<?php

namespace app\modules\api\controllers;

use app\actions\SubmitFormAction;
use app\behaviors\spamchecker\SpamCheckerBehavior;
use app\components\Controller;
use app\models\SpamChecker;
use app\models\Submission;
use app\modules\review\models\RatingItem;
use app\modules\review\models\RatingValues;
use app\modules\review\models\Review;
use Yii;
use yii\helpers\Json;
use yii\web\HttpException;
use app\modules\api\components\ RestController;
use kartik\widgets\ActiveForm;
use yii\helpers\Url;
use yii\data\Pagination;


class ReviewController extends  RestController
{
    
    protected $pageSize = 5;
    protected $page = 0;
    
    public function actions()
    {
        return [
            'submission' => [
              'class' => SubmitFormAction::className(),
            ],
        ];
    }
    
    public function beforeAction($action)
    {
        $action_array = [
                         'actionCreate',
                        ];
        
        if(in_array($action->actionMethod, $action_array))
           $this->_checkAuth();
        return parent::beforeAction($action);
    } 

    /**
     * @param $objectModelId
     */
    public function actionCreate($objectModelId)
    {
        if (false === Yii::$app->request->isPost) {
             return $this->_sendResponse(403);  
        }
        /** @var $review \app\modules\review\models\Review|SpamCheckerBehavior */
        $post = Yii::$app->request->post();
        $review = new Review(['scenario' => 'check']);
        $review->review_text = Yii::$app->request->post('review_text');
        if (!Yii::$app->user->isGuest) {
            $review->author_email = Yii::$app->user->identity->email;
        }
        $review->object_id = 1;
        $review->object_model_id = $objectModelId;
        
        if ($review->validate()) {
            $submission_id = Yii::$app->runAction('/api/review/submission', ['id' =>1]);
            if ($submission_id == "0") {
               return $this->_sendResponse(401,Yii::t('app', 'Error occurred while saving review. Sorry. Try again later'),'message');
            }
            $review->submission_id = $submission_id;
            $review->status = Review::STATUS_APPROVED;
            if (Yii::$app->getModule('review')->enableSpamChecking) {
                $activeSpamChecker = SpamChecker::getActive();
                if (!is_null($activeSpamChecker) && !empty($activeSpamChecker->api_key)) {
                    $review->attachBehavior(
                        'spamChecker',
                        [
                            'class' => SpamCheckerBehavior::className(),
                            'data' => [
                                $activeSpamChecker->name => [
                                    'class' => $activeSpamChecker->behavior,
                                    'value' => [
                                        'key' => $activeSpamChecker->api_key,
                                        SpamChecker::FIELD_TYPE_CONTENT => $review->review_text
                                    ],
                                ],
                            ],
                        ]
                    );
                    if ($review->isSpam()) {
                        $review->status = Review::STATUS_NOT_APPROVED;
                        Submission::updateAll(['spam' => 1], ['id' => $submission_id]);
                    }
                }
            }
            if ($review->save()) {
                $ratingData = isset($post['ObjectRating']) ? $post['ObjectRating'] : null;
                if (null !== $ratingData) {
                    $group = isset($ratingData['group']) ? trim($ratingData['group']) : null;
                    $group = RatingItem::getGroupByName($group);
                    $items = [];
                    if (!empty($ratingData['values']) && !empty($group)) {
                        $user_id = \Yii::$app->getUser()->isGuest ? 0 : \Yii::$app->user->identity->getId();
                        $ratingId = md5(Json::encode(array_merge($ratingData['values'], [microtime(), $user_id])));
                        $date = date('Y-m-d H:m:s');
                        if ((0 == $group['require_review']) || ((0 != $group['require_review']))) {
                            $items = RatingItem::getItemsByAttributes(
                                ['rating_group' => $group['rating_group']],
                                true,
                                true
                            );
                        }
                        if (!empty($items)) {
                            foreach ($items as $key => $item) {
                                $model = new RatingValues();
                                $model->loadDefaultValues();
                                $model->object_id = 1;
                                $model->object_model_id = $objectModelId;
                                $model->rating_item_id = $item['id'];
                                $model->value = isset($ratingData['values'][$item['id']])
                                    ? intval($ratingData['values'][$item['id']])
                                    : 0;
                                $model->rating_id = $ratingId;
                                $model->date = $date;
                                $model->save();
                            }
                            if (isset($review)) {
                                $review->rating_id = $ratingId;
                                $review->save(true, ['rating_id']);
                            }
                        }
                    }
                }
               return $this->_sendResponse(200, Yii::t('app', 'Success'));  
            }
        }else
            return $this->_sendResponse(401,ActiveForm::validate($review),'message');     
    }
    
    public function actionList($id)
    {
     if(trim(Yii::$app->request->get('pageSize')) != '')
            $this->pageSize = Yii::$app->request->get('pageSize');
        
     if(trim(Yii::$app->request->get('page')) != '')
             $this->page = Yii::$app->request->get('page');   
        
     if(Yii::$app->request->get('id') AND trim(Yii::$app->request->get('id')) != '')
     {
        $query      = Review::find()->where(['object_model_id'=>$id]);
        $countQuery = clone $query;
        $pages      = new Pagination(['totalCount' => $countQuery->count(),'defaultPageSize'=>$this->pageSize,'page'=>$this->page]);
        $reviews    = $query->offset($pages->offset)
                            ->limit($pages->limit)
                            ->all();
        
         $data['pagination'] = [
                                    'totalCount'      =>$pages->totalCount,
                                    'defaultPageSize' =>$pages->defaultPageSize,
                               ];  
        
        $url = Url::to(['/'], true);
        foreach($reviews as $review){
          $user = \app\modules\user\models\User::findIdentity($review->submission->processed_by_user_id);
          $data['reviews'][] = [
                                'review_text' => $review->review_text,
                                'user'=>[
                                         'name'=>$user->getDisplayName(),
                                         'image'       => $url.substr($user->getThumbnail(100,100),1) ,
                                        ]
                               ];
        }
            return $this->_sendResponse(200,$data);    
     }else
         return $this->_sendResponse(401,'$_GET[id] not fount or empty','message');    
    }
}
