<?php
namespace app\modules\api\controllers\medbase;

use app\modules\medbase\models\Clinic;
use app\modules\medbase\models\ClinicCategory;
use app\modules\medbase\models\ClinicCategoryDiscount;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use \Yii;
use app\modules\api\components\ApiRestController;
use app\modules\core\models\Language;
use app\modules\user\models\User;
use yii\caching\TagDependency;
use yii\filters\AccessControl;
use yii\web\UploadedFile;
use yii\data\Pagination;
use yii\web\Response;
use yii\helpers\Json;
use yii\helpers\Url;
use kartik\widgets\ActiveForm;
use yii\db\Query;


class ClinicController extends  ApiRestController
{
    protected $pageSize = 5;
    protected $page = 0;

    public function beforeAction($action) {
        $json_data = file_get_contents('php://input');
        $data_array = Json::decode($json_data);

        if(!empty($data_array['pageSize']))
            $this->pageSize = $data_array['pageSize'];

        if(!empty($data_array['page']))
            $this->page = $data_array['page'];

        return parent::beforeAction($action);
    }

    public function actionView()
    {
        $this->checkAuth();
        $url = Yii::$app->request->hostInfo;
        $user = User::findIdentity(Yii::$app->user->id);

        if($clinic_id = $user->getOperatorClinic()->one()->clinic_id) {

            $clinic = Clinic::find()->where('id='.$clinic_id)->one();

            if ($clinic->getMainImage()->one())
                $image = $url . $clinic->getMainImage()->one()->file_name;
            else
                $image = $url . 'files/images/not_foto.jpg';

            $data = [
                     'id'               => $clinic->id,
                     'name'             => $clinic->name,
                     'address'          => $clinic->address,
                     'discount'         => $clinic->discount,
                     'image'            => $image,
                     'full_description' => $clinic->full_description,
                    ];
            return $this->_sendResponse(200,$data);
        } else
            return $this->_sendResponse(200, 'Clinic not found', 'message',false);
    }

    public function actionCategory()
    {
        $this->checkAuth();

        $user = User::findIdentity(Yii::$app->user->id);

        if($clinic_id = $user->getOperatorClinic()->one()->clinic_id) {

        /*
        $countQuery = clone $clinicCategory;
        $pages = new Pagination([
            'totalCount' => $countQuery->count(),
            'defaultPageSize'=>$this->pageSize,
            'page'=>$this->page
        ]);

        $data['pagination'] = [
            'totalCount'      =>$pages->totalCount,
            'defaultPageSize' =>$pages->defaultPageSize,
        ];

        $clinicCategory = $clinicCategory->offset($pages->offset)
            ->limit($pages->limit)
            ->all();
        */

            $cacheKey = "clinic_category_api_".$this->id;

            $data = Yii::$app->cache->get($cacheKey);


            if ($data === false) {

                $clinic = $user->getOperatorClinic()->one();

                $clinicCategory = ClinicCategory::find()->where(['clinic_id'=>$clinic->clinic_id])->all();

                foreach($clinicCategory as $category)
                    $data['clinicCategory'][] = [
                        'id'                  => $category->id,
                        'name'                => $category->getCategory()->one()->name,
                        'price'               => $category->price,
                        'notes'               => $category->notes,
                        'discount'            => $category->getDiscount(),
                        'short_description'   => $category->short_description
                    ];

                Yii::$app->cache->set(
                    $cacheKey,
                    $data,
                    86400,
                    new TagDependency([
                        'tags' => [
                            ActiveRecordHelper::getCommonTag(ClinicCategory::className()),
                            ActiveRecordHelper::getCommonTag(ClinicCategoryDiscount::className())
                        ]
                    ])
                );
            }
        return $this->_sendResponse(200, $data);

        } else
            return $this->_sendResponse(200, 'Clinic not found', 'message',false);
    }
}
?>