<?php
namespace app\modules\api\controllers\medbase;

use app\modules\medbase\models\MedHistoryFile;
use app\modules\medbase\models\MedHistoryLog;
use \Yii;
use app\modules\medbase\models\ClinicCategoryDiscount;
use app\modules\api\components\ApiRestController;
use app\modules\medbase\models\ClinicCategory;
use app\modules\medbase\models\MedHistory;
use app\modules\medbase\models\Clinic;
use app\modules\core\models\Language;
use app\modules\user\models\User;
use kartik\widgets\ActiveForm;
use yii\filters\AccessControl;
use yii\web\UploadedFile;
use yii\data\Pagination;
use yii\web\Response;
use yii\helpers\Json;
use yii\helpers\Url;
use yii\db\Query;

class MedHistoryController extends  ApiRestController
{
    protected $pageSize = 5;
    protected $page = 0;
    protected $uploadDir = '/upload/history/';


    public function beforeAction($action)
    {
        $json_data = file_get_contents('php://input');
        $data_array = json_decode($json_data, true);

        if(!empty($data_array['pageSize']))
            $this->pageSize = $data_array['pageSize'];

        if(!empty($data_array['page']))
            $this->page = $data_array['page'];

        return parent::beforeAction($action);
    }

    public function UploadFile($model,$file)
    {
        if ($file !== null)
        {
            $prefx = rand(100,999).'_'.time();

            $fileName  = $model->id.'_'.$prefx.'.'.$file->extension;

            if(!file_exists(Yii::getAlias('@webroot'.$this->uploadDir)))
                mkdir(Yii::getAlias('@webroot'.$this->uploadDir),0777);

            $uploadDir = Yii::getAlias('@webroot'.$this->uploadDir);

            $fn = $uploadDir . $fileName;

            $file->saveAs($fn);

            return str_replace(Yii::getAlias('@webroot'), '', $uploadDir).$fileName;
        }else
            return $this->_sendResponse(200, 'Error upload file',false);
    }

    public function actionUpload() {

        $this->checkAuth();

        $request = Yii::$app->request;
        $url = Yii::$app->request->hostInfo;

        $extension = ['jpg'=>'jpg','png'=>'png','zip'=>'zip','pdf'=>'pdf','docx'=>'docx','doc'=>'doc'];

        if($request->post("history_id")) {

            $description = $request->post("descriotion");

            if($_FILES['file']) {
                if(!$medHistory = MedHistory::find()->where('id='.$request->post("history_id"))->one())
                    return $this->_sendResponse(200, 'Med history not found', 'message',false);

                $files =  UploadedFile::getInstancesByName('file');

                $i = 0;
                foreach($files as $file){



                    if(array_key_exists($file->extension,$extension)) {

                        $medHistoryFile               = new MedHistoryFile;
                        $medHistoryFile->history_id   = $medHistory->id;
                        $medHistoryFile->file_name    = $this->UploadFile($medHistory,$file);
                        $medHistoryFile->description  = $description[$i];

                        if($medHistoryFile->save()) {
                            $data[] = [
                                'file'=>$url.$medHistoryFile->file_name
                            ];
                        }else
                            $data[] = [
                                'file'=> $file->name.': Error'
                            ];
                    }else
                        $data[] = [
                            'file'=> $file->name.': Only the (jpg, png, zip, pdf, doc, docx) allowed'
                        ];
                    $i++;
                }

                return $this->_sendResponse(200,$data);
            }else
                return $this->_sendResponse(200, 'file not come', 'message',false);
        }else
            return $this->_sendResponse(200, 'history_id not come', 'message',false);
    }

    public function actionList()
    {
        $this->checkAuth();
        $url      = Yii::$app->request->hostInfo;
        $operator = User::findIdentity(Yii::$app->user->id);

        $json_data = file_get_contents('php://input');
        $data_array = json_decode($json_data, true);

        if(!empty($data_array['key'])) {

            $clinic_id = $operator->getOperatorClinic()->one()->clinic_id;
            $clinic = Clinic::find()->where('id='.$clinic_id)->one();
            if(!$patient = User::findKey($data_array['key']))
                return $this->_sendResponse(200, 'Incorrect patient key', 'message',false);

            $medHistory = MedHistory::find()
                            ->where([
                                      'patient_id'=>$patient->id
                                    ]);

            if(!empty($data_array['filter']['category_id']))
                $medHistory->andFilterWhere(['medHistory.category_id' => $data_array['filter']['category_id']]);

            if(!empty($data_array['filter']['date_before']) AND !empty($data_array['filter']['date_end']))
                $medHistory->andFilterWhere(['BETWEEN', '"medHistory"."date_created"', $data_array['filter']['date_before'], $data_array['filter']['date_end']]);


            $countQuery = clone $medHistory;
            $pages = new Pagination([
                                      'totalCount' => $countQuery->count(),
                                      'defaultPageSize'=>$this->pageSize,
                                      'page'=>$this->page
                                    ]);
            $medHistory = $medHistory->offset($pages->offset)
                                     ->limit($pages->limit)
                                     ->all();

            $data['pagination'] = [
                'totalCount'      =>$pages->totalCount,
                'defaultPageSize' =>$pages->defaultPageSize,
            ];

            foreach( $medHistory as $history) {

                $file_count = 0;

                if($history->getFiles()->all())
                    $file_count = $history->getFiles()->count();

                $data['medHistory'][] = [
                                        'id'       => $history->id,
                                        'title'    => $history->title,
                                        'category' => $history->getCategory()->one()->name,
                                        'create'   => $history->date_created,
                                        'clinic'   => $history->getClinic()->one()->name,
                                        'file'     => $file_count,
                                        ];

            }

            return $this->_sendResponse(200,$data);
        }else
            return $this->_sendResponse(200, 'Key patient not come', 'message',false);
    }

    public function actionCreate(){

        $this->checkAuth();

        $json_data = file_get_contents('php://input');
        $data_array = json_decode($json_data, true);

        if(!empty($data_array['key']) OR !empty($data_array['patient_id'])) {

            if(!empty($data_array['key'])) {

                $user = User::find()->where(['key'=>$data_array['key']])->one();

                if(!$patient = User::findKey($data_array['key']))
                    return $this->_sendResponse(200, 'Incorrect patient key', 'message',false);
            }else {
                if(!$patient = User::find()->where('id='.$data_array['patient_id'])->one())
                    return $this->_sendResponse(200, 'User not found', 'message',false);
            }

            $operator = User::findIdentity(Yii::$app->user->id);

            $clinic_id      = $operator->getOperatorClinic()->one()->clinic_id;
            $clinic         = Clinic::find()->where('id='.$clinic_id)->one();

            $medHistory             = new MedHistory();
            $medHistory->load($data_array);
            $medHistory->user_id    = $operator->id;
            $medHistory->patient_id = $patient->id;
            $medHistory->clinic_id  = $clinic->id;
            $medHistory->price      = $clinic->calculateDiscountPrice($medHistory->category_id,$medHistory->date_putting_analyzes);

            if($medHistory->validate()) {
                if($medHistory->save()) {
                    $data = [
                             'id'=>$medHistory->id,
                            ];

                       return $this->_sendResponse(200,$data);
                }else
                    return $this->_sendResponse(200,'Error save','message',false);
            }else
                return $this->_sendResponse(200,ActiveForm::validate($medHistory),'data',false);
        }else
            return $this->_sendResponse(200, 'key or id patient not come', 'message',false);
    }

    public function actionView()
    {
        $this->checkAuth();

        $url      = Yii::$app->request->hostInfo;
        $operator = User::findIdentity(Yii::$app->user->id);

        $json_data = file_get_contents('php://input');
        $data_array = json_decode($json_data, true);

        if(!empty($data_array['key']) AND !empty($data_array['history_id'])) {

            if(!$patient = User::findKey($data_array['key']))
                return $this->_sendResponse(200, 'Incorrect patient key', 'message',false);

            if(!$medHistory = MedHistory::find()->where(['id'=>$data_array['history_id']])->one())
                return $this->_sendResponse(200, 'Med history not found', 'message',false);

            $files = null;
            if($medHistoryFiles = MedHistoryFile::find()->where(['history_id'=>$medHistory->id])->all())

                foreach($medHistoryFiles as $file)
                    $files[] = [
                                 'url'         => $url.$file->file_name,
                                 'descriotion' => $file->description,
                                 'size'        => $file->getFileSize(),
                               ];

                $data = [
                            'title'                 => $medHistory->title,
                            'description'           => $medHistory->description,
                            'complaints_symptom'    => $medHistory->complaints_symptom,
                            'diagnosis'             => $medHistory->diagnosis,
                            'doctor_conclusion'     => $medHistory->doctor_conclusion,
                            'doctor_recommendation' => $medHistory->doctor_recommendation,
                            'note'                  => $medHistory->note,
                            'files'                 => $files,
                            'doctor'                => $medHistory->getDoctorDataArray(),
                            'clinic'                => $medHistory->getClinicDataArray(),
                        ];

            MedHistoryLog::addLog($medHistory->id,false,false,MedHistoryLog::ACTION_VIEW);

            return $this->_sendResponse(200,$data);
        }else
            return $this->_sendResponse(200, 'Key patient or history id not come', 'message',false);

    }
}
?>