<?php
namespace app\modules\api\controllers\medbase;

use devgroup\TagDependencyHelper\ActiveRecordHelper;
use \Yii;
use app\modules\api\components\ApiRestController;
use app\modules\core\models\Language;
use app\modules\user\models\User;
use yii\caching\TagDependency;
use yii\filters\AccessControl;
use yii\web\UploadedFile;
use yii\data\Pagination;
use yii\web\Response;
use yii\helpers\Json;
use yii\helpers\Url;
use kartik\widgets\ActiveForm;
use yii\db\Query;

class UserController extends  ApiRestController
{
    protected $pageSize = 5;
    protected $page = 0;

    public function beforeAction($action){

        $json_data = file_get_contents('php://input');
        $data_array = Json::decode($json_data);

        if(!empty($data_array['pageSize']))
            $this->pageSize = $data_array['pageSize'];

        if(!empty($data_array['page']))
            $this->page = $data_array['page'];

        return parent::beforeAction($action);
    }

    public function actionSearch()
    {
        $json_data = file_get_contents('php://input');
        $data_array = Json::decode($json_data);

        if ($search = $data_array['search']) {

            $query = new Query;
            $query->select('u.id, u.username, u.phone, ut.first_name, ut.last_name')
                ->leftJoin('userTranslate ut', 'ut.user_id = u.id')
                ->from('user u')
                ->orWhere(['u.phone' => $search])
                ->orWhere('u.username LIKE "%' . $search . '%"')
                ->orWhere('ut.first_name LIKE "%' . $search . '%"')
                ->orWhere('ut.last_name LIKE "%' . $search . '%"')
                ->groupBy(['u.id']);
            $command = $query->createCommand();
            $data = $command->queryAll();

            return $this->_sendResponse(200, $data);
        } else
            return $this->_sendResponse(200, 'Not all attributes come', 'message',false);
    }

    public function actionView()
    {
        $this->checkAuth();
        $url = Yii::$app->request->hostInfo . '/';
        $json_data = file_get_contents('php://input');
        $data_array = Json::decode($json_data);

        if ($id = trim($data_array['id'])) {

            $user = User::find()->where(['id' => $id])->one();

            if(!$user)
                return $this->_sendResponse(200, 'User not found', 'message',false);

            if ($user->image)
                $image = $url . 'files/' . $user->image;
            else
                $image = $url . 'files/images/user-no-image.jpg';

            $data = [
                'id'          => $user->id,
                'image'       => $image,
                'first_name'  => $user->first_name,
                'last_name'   => $user->last_name,
                'middle_name' => $user->middle_name,
                'country'     => ($user->country_id != "") ? $user->getCountry()->one()->name : 'null',
                'city'        => ($user->city_id != "") ? $user->getCity()->one()->name : 'null',
            ];

            return $this->_sendResponse(200, $data);
        } else
            return $this->_sendResponse(200, 'Not all attributes come', 'message',false);
    }

    public function actionKey()
    {

        $this->checkAuthKey();

        $json_data = file_get_contents('php://input');
        $data_array = Json::decode($json_data);

        if ($id = trim($data_array['id'])) {

            $user = User::find()->where(['id' => $id])->one();

            if(!$user)
                return $this->_sendResponse(200, 'User not found', 'message',false);

            if($data_array['generator_key'] == "yes") {
                $user->scenario = 'key';
                $user->key = $user->getKey();
                $user->save();
            }

            $data = [
                      'id'  => $user->id,
                      'key' => $user->key,
                    ];
            return $this->_sendResponse(200, $data);
        } else
            return $this->_sendResponse(200, 'Not all attributes come', 'message',false);

    }

    public function actionDoctors()
    {
        $this->checkAuthKey();
        $json_data = file_get_contents('php://input');
        $data_array = Json::decode($json_data);

        $cacheKey = "doctor_array_api_";

        $data = Yii::$app->cache->get($cacheKey);


        if ($data === false) {
            $doctors = User::find()->where(['user_type'=>2,'doctor_active'=>1])->all();;

            foreach($doctors as $doctor){
                $data['doctors'][] =[
                    'id'          =>$doctor->id,
                    'first_name'  =>$doctor->first_name,
                    'last_name'   =>$doctor->last_name,
                    'middle_name' =>$doctor->middle_name,
                    'specialty'   =>$doctor->getSpecialty()->name,
                    'clinic'      =>$doctor->getClinic()->name,
                ];
            }

            Yii::$app->cache->set(
                $cacheKey,
                $data,
                86400
            );
        }

        /*
        if ($search = $data_array['search']) {

            $doctors->leftJoin('userTranslate ut', 'ut.user_id = `user`.id')
                    ->andWhere('( ut.first_name LIKE "' . $search . '%" OR
                                  ut.last_name LIKE "' . $search . '%" OR
                                  ut.middle_name LIKE "' . $search . '%" )')
                    ->groupBy(['`user`.`id`']);
        }

        if ($id = $data_array['id']) {
            $doctors->andWhere(['id'=>602]);
        }

        $countQuery = clone $doctors;
        $pages = new Pagination([
            'totalCount' => $countQuery->count(),
            'defaultPageSize'=>$this->pageSize,
            'page'=>$this->page
        ]);

        $data['pagination'] = [
            'totalCount'      =>$pages->totalCount,
            'defaultPageSize' =>$pages->defaultPageSize,
        ];

        $doctors = $doctors->offset($pages->offset)
            ->limit($pages->limit)
            ->all();
        */


        return $this->_sendResponse(200, $data);
    }

}
?>