<?php

namespace app\modules\api\models;

use Yii;
use app\modules\askdoctor\models\QuestionsTheme;
use app\modules\user\models\User;
use PHP_GCM\Sender;
use PHP_GCM\Message;

/**
 * This is the model class for table "google_cloud_messaging".
 *
 * @property integer $id
 * @property string $email
 * @property integer $name
 * @property string $user_id
 * @property string $gcm_regid
 * @property string $date_created
 */
class GoogleCloudMessaging extends \yii\db\ActiveRecord
{
    
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'gcm_users';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['gcm_regid'], 'required'],
            [['user_id','name', 'email','date_created' ], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'           => 'ID',
            'name'         => 'Name',
            'email'        => 'Email',
            'user_id'      => 'User',
            'gcm_regid'    => 'GCM Reg ID',
            'date_created' => 'Date created',
            
        ];
    }
    
    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 1,
                ],
            ]
        );
        
        if (!($this->load($params))) {
            return $dataProvider;
        }
        return $dataProvider;
    }
    
    public function beforeSave()
    {
      if($this->isNewRecord){
        if($gcm_regid = GoogleCloudMessaging::find()->where(['gcm_regid'=>"".$this->gcm_regid.""])->all())
           {
            foreach($gcm_regid as $reg_id)
            $reg_id->delete();  
           }
           
        $this->date_created = date('Y-m-j',time());
      }
       return parent::beforeSave(true);
    }
    
    public function sendMessageUser($id,$message)
    {
        $model = GoogleCloudMessaging::find()->where(['user_id'=>$id])->one();
        
        $registatoin_ids = [$model->gcm_regid];
                    
        $message = ["message" => $message];
        
        return $this->sendNotification($registatoin_ids,$message);
    }
    
     /**
     * Sending Push Notification
     */
    public function sendNotification($registatoin_ids, $message) {

        $gcm = Yii::$app->gcm;
        $result =   $gcm->sendMulti($registatoin_ids, $message,
            [
                'customerProperty' => 1,
            ],
            [
                'timeToLive' => 3
            ]);

        return [$result->getResults()];
    }
    
    public static function sendPushNotificationChat($question) {

        $theme = QuestionsTheme::find()->where(['id'=>$question->theme_id])->one();
        $user = User::find()->where(['id'=>$question->user_id])->one();
        
        $url = Yii::$app->request->hostInfo.'/';
        
        if($user->user_type == 1)
        {
          if($theme->status  == 1){
              $doctor = User::find()->where(['id'=>$theme->doctor_id])->one();
              
              if($doctor->push_notification == 1)
              {
                  $gcm = GoogleCloudMessaging::find()->where(['user_id'=>$doctor->id])->one();  
                  $apn = ApplePushNotification::find()->where(['user_id'=>$doctor->id])->one();
                  
                  $message = ["message" =>  [
                                             "theme_id"  => $theme->id,
                                             "user_id"   => $doctor->id,
                                             "user_name" => $user->first_name.' '. $user->last_name,
                                             "image"     => $url.'files/'.$doctor->image,
                                             "specialti" => $doctor->getSpecialty()->name,
                                             "usertype"  => $user->user_type,
                                             "message"   => $question->text
                                            ]
                                 ];
                  $message_ = ["message" => [
                                             "theme_id"  => $theme->id,
                                             "user_id"   => $doctor->id,
                                             "user_name" => $user->first_name.' '. $user->last_name,
                                             "usertype"  => $doctor->user_type,
                                             "message"   => substr($question->text,0,50)
                                            ]
                                 ];
                  
                  
                  if($gcm){
                      $registatoin_ids = [$gcm->gcm_regid];
                      $gcm->sendNotification($registatoin_ids, $message);
                  }
                  
                  if($apn){
                    $deviceToken = $apn->deviceToken;
                    $apn->sendNotification($deviceToken, $message_);
                  }
              }

          }
        }else if($user->user_type == 2){
            
              $user_ = User::find()->where(['id'=>$theme->user_id])->one();
              
              if($user_->push_notification == 1)
              {
                  $gcm = GoogleCloudMessaging::find()->where(['user_id'=>$user_->id])->one(); 
                  $apn = ApplePushNotification::find()->where(['user_id'=>$user_->id])->one(); 
                  
                  $message = ["message" => [
                                                 "theme_id"  => $theme->id,
                                                 "user_id"   => $user_->id,
                                                 "user_name" => $user->first_name.' '. $user->last_name,
                                                 "image"     => $url.'files/'.$user_->image,
                                                 "specialti" => "null",
                                                 //"usertype"  => $user->user_type,
                                                 "message"   => $question->text
                                                ]
                                 ];
                  
                  $message_ = ["message" => [
                                             "theme_id"  => $theme->id,
                                             "user_id"   => $user_->id,
                                             "user_name" => $user->first_name.' '. $user->last_name,
                                             "usertype"  => $user_->user_type,
                                             "message"   => substr($question->text,0,50)
                                            ]
                                 ];
                  
                  if($gcm){
                     $registatoin_ids = [$gcm->gcm_regid];
                     $gcm->sendNotification($registatoin_ids, $message);
                  }
                  
                  if($apn){
                    $deviceToken = $apn->deviceToken;
                    $apn->sendNotification($deviceToken, $message_);
                  }
              }
        }
    }
    
}
