<?php

namespace app\modules\catalog\controllers;

use Yii;
use app\modules\catalog\models\Category;
use app\backend\components\BackendController;
use yii\web\NotFoundHttpException;
use yii\filters\AccessControl;
use tree\JsTreeWidget\FullTreeDataAction;
use app\modules\image\widgets\SaveInfoAction;
use yii\helpers\Url;

/**
 * BackendCategoryController implements the CRUD actions for Category model.
 */
class BackendCategoryController extends BackendController
{
    public function actions()
    {
        return [
            'getTree' => [
                'class' => FullTreeDataAction::className(),
                'class_name' => Category::className(),
                'model_label_attribute' => 'name',
                'query_sort_order'=>['root' => SORT_ASC, 'lft' => SORT_ASC ]
            ],
            'save-info' => [
                'class' => SaveInfoAction::className(),
            ],
        ];
    }

    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['content manage'],
                    ],
                ],
            ],
        ];
    }

    /**
     * Lists all Category models.
     * @return mixed
     */

    public function actionIndex($parent = 1)
    {
        $searchModel = new Category();

        $params = Yii::$app->request->get();
        $dataProvider = $searchModel->search($params);

        return $this->render(
            'index',
            [
                'dataProvider' => $dataProvider,
                'searchModel' => $searchModel,
            ]
        );
    }

    public function actionEdit($parent_id = false, $id = null, $new = true) {

        $model = new Category;
        if ($id !== null) {
            $model = Category::find()->where(['id'=>$id])->multilingual()->one();
            if ($model === null) {
                throw new NotFoundHttpException;
            }
        }


        if ($model->load(Yii::$app->request->post())) {

            if($parent_id == false)
                $root = Category::find()->where("slug = ':mainroot:' ")->one();
            else
                $root = Category::findOne($parent_id);

            if($model->isNewRecord)
                $model->appendTo($root);

            if ($model->save()) {

                Yii::$app->session->setFlash('info', Yii::t('app', 'Object saved'));
                $returnUrl = Yii::$app->request->get('returnUrl');
                switch (Yii::$app->request->post('action', 'save')) {
                    case 'next':
                        return $this->redirect(
                            [
                                '/catalog/backend-category/edit',
                                'returnUrl' => $returnUrl,
                                'parent_id' => Yii::$app->request->get('parent_id', null)
                            ]
                        );
                    case 'back':
                        return $this->redirect($returnUrl);
                    default:
                        return $this->redirect(
                            Url::toRoute(
                                [
                                    '/catalog/backend-category/edit',
                                    'id' => $model->id,
                                    'returnUrl' => $returnUrl,
                                    'parent_id' => $model->parents(1)->one()->id
                                ]
                            )
                        );
                }
            }else
                Yii::$app->session->setFlash('error', Yii::t('app', 'Cannot update data'));
        }

        return $this->render('edit', [
            'model' => $model,
        ]);
    }

    public function actionDelete($id) {
        $model = $this->findModel($id);
        $model->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Category model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Category the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Category::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
