<?php
namespace app\modules\catalog\controllers;

use Yii;
use app\modules\image\widgets\SaveInfoAction;
use app\backend\components\BackendController;
use app\modules\catalog\models\CategoryType;
use yii\filters\AccessControl;
use yii\filters\VerbFilter;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\web\BadRequestHttpException;
use yii\web\Response;

class BackendCategoryTypeController extends BackendController {

    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['regions manage'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    public function actions()
    {
        return [
            'save-info' => [
                'class' => SaveInfoAction::className(),
            ],
        ];
    }

    /**
     * Lists all CategoryType models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new CategoryType();

        $params = Yii::$app->request->get();
        $dataProvider = $searchModel->search($params);

        return $this->render(
            'index',
            [
                'dataProvider' => $dataProvider,
                'searchModel' => $searchModel,
            ]
        );
    }

    public function actionEdit($id = null) {

        $model = new CategoryType;
        if ($id !== null) {
            $model = CategoryType::find()->where(['id'=>$id])->one();
            if ($model === null) {
                throw new NotFoundHttpException;
            }
        }

        if ($model->load(Yii::$app->request->post())) {

            if ($model->save()) {

                Yii::$app->session->setFlash('info', Yii::t('app', 'Object saved'));
                $returnUrl = Yii::$app->request->get('returnUrl');
                switch (Yii::$app->request->post('action', 'save')) {
                    case 'next':
                        return $this->redirect(
                            [
                                '/catalog/backend-category-type/edit',
                                'returnUrl' => $returnUrl,
                            ]
                        );
                    case 'back':
                        return $this->redirect($returnUrl);
                    default:
                        return $this->redirect(
                            Url::toRoute(
                                [
                                    '/catalog/backend-category-type/edit',
                                    'id' => $model->id,
                                    'returnUrl' => $returnUrl,
                                ]
                            )
                        );
                }
            }else
                Yii::$app->session->setFlash('error', Yii::t('app', 'Cannot update data'));
        }
        return $this->render('edit', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing CategoryType model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $model = $this->findModel($id);
        $model->delete();

        return $this->redirect(['index']);
    }

    public function actionUpdateCategoryType()
    {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $post = Yii::$app->request->post();

        if (!isset($post['editableIndex'], $post['editableKey'])) {
            throw new BadRequestHttpException;
        }

        $id = $post['editableKey'];
        /** @var User Package */
        $model = CategoryType::findOne($id);
        if ($model === null) {
            throw new BadRequestHttpException;
        }

        $index = $post['editableIndex'];
        if (!is_array($post['CategoryType'][$index])) {
            throw new BadRequestHttpException;
        }

        if (count($post['CategoryType'][$index])===0) {
            throw new BadRequestHttpException;
        }

        $modifiedAttribute = array_keys($post['CategoryType'][$index])[0];

        $model->setAttributes($post['CategoryType'][$index]);

        if (!$model->save()) {
            return [
                'message' => Yii::t('app', 'Cannot save object'),
            ];
        }

        if ($modifiedAttribute === 'status') {
            if ($model->status == 0) {
                $label_class = 'label-default';
                $value = CategoryType::getStatusLabel(CategoryType::STATUS_INACTIVE);
            }elseif ($model->status == 1) {
                $label_class = 'label-success';
                $value = CategoryType::getStatusLabel(CategoryType::STATUS_ACTIVE);}

            $model->status = Html::tag(
                'span',
                Yii::t('app', $value),
                ['class' => "label $label_class"]
            );

        }

        return [
            'output' => $model->getAttribute($modifiedAttribute),
        ];
    }

    /**
     * Finds the CategoryType model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return CategoryType the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = CategoryType::find()->where(['id'=>$id])->multilingual()->one()) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested object does not exist.');
        }
    }
}