<?php

namespace app\modules\catalog\models;


use Yii;
use app\behaviors\Tree;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use app\modules\core\models\Language;
use omgdef\multilingual\MultilingualBehavior;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\helpers\ArrayHelper;
use yii\db\ActiveRecord;
use app\modules\page\models\Page;
use app\modules\catalog\models\CategoryType;

class Category extends ActiveRecord
{

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;

    public $c3_count;

    // use MultilingualTrait;

    private static $identity_map = [];

    /**
     * @var string the classname for the TreeQuery that implements the NestedSetQueryBehavior.
     * If not set this will default to `kartik\tree\models\TreeQuery`.
     */
    public static $treeQueryClass;

    /**
     * @var bool whether to HTML encode the tree node names. Defaults to `true`.
     */
    public $encodeNodeNames = true;

    /**
     * @var bool whether to HTML purify the tree node icon content before saving.
     * Defaults to `true`.
     */
    public $purifyNodeIcons = true;

    /**
     * @var array activation errors for the node
     */
    public $nodeActivationErrors = [];

    /**
     * @var array node removal errors
     */
    public $nodeRemovalErrors = [];

    /**
     * @var bool attribute to cache the `active` state before a model update. Defaults to `true`.
     */
    public $activeOrig = true;

    use \kartik\tree\models\TreeTrait {
        isDisabled as parentIsDisabled; // note the alias
        behaviors as treeBehaviors;
    }

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%category}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['slug', 'name','type'], 'required'],
            [['root', 'lft', 'rgt', 'lvl', 'icon_type', 'active', 'selected', 'disabled', 'readonly', 'visible', 'collapsed', 'movable_u', 'movable_d', 'movable_l', 'movable_r', 'removable', 'removable_all', 'sort_order'], 'integer'],
            [['lft', 'rgt', 'lvl','content','description','slug','slug_compiled','slug_absolute','status'], 'safe'],
            [['name', 'icon'], 'string', 'max' => 255],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'            => Yii::t('app', 'ID'),
            'name'          => Yii::t('app', 'Name'),
            'description'   => Yii::t('app', 'Description'),
            'content'       => Yii::t('app', 'Content'),
            'root'          => Yii::t('app', 'Root'),
            'lft'           => Yii::t('app', 'Lft'),
            'rgt'           => Yii::t('app', 'Rgt'),
            'lvl'           => Yii::t('app', 'Lvl'),
            'icon'          => Yii::t('app', 'Icon'),
            'icon_type'     => Yii::t('app', 'Icon Type'),
            'active'        => Yii::t('app', 'Active'),
            'selected'      => Yii::t('app', 'Selected'),
            'disabled'      => Yii::t('app', 'Disabled'),
            'readonly'      => Yii::t('app', 'Readonly'),
            'visible'       => Yii::t('app', 'Visible'),
            'collapsed'     => Yii::t('app', 'Collapsed'),
            'movable_u'     => Yii::t('app', 'Movable U'),
            'movable_d'     => Yii::t('app', 'Movable D'),
            'movable_l'     => Yii::t('app', 'Movable L'),
            'movable_r'     => Yii::t('app', 'Movable R'),
            'removable'     => Yii::t('app', 'Removable'),
            'removable_all' => Yii::t('app', 'Removable All'),
            'slug'          => Yii::t('app', 'Slug'),
            'slug_compiled' => Yii::t('app', 'Slug Compiled'),
            'slug_absolute' => Yii::t('app', 'Slug Absolute'),
            'type'          => Yii::t('app', 'Type'),
            'sort_order'    => Yii::t('app', 'Sort Order'),
        ];
    }

    public function search($params)
    {
        $query = self::find()->nonRoot();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if($params['parent_id']) {
            if($parent = Category::find()->where('id ='.$params['parent_id'])->one())
                $query->where('lft > '.$parent->lft.' AND rgt < '.$parent->rgt.' AND lvl = '.($parent->lvl + 1));
        }

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->andFilterWhere([self::tableName().'.type' => $this->type]);
        $query->andFilterWhere([self::tableName().'.sort_order' => $this->sort_order]);
        $query->join('LEFT JOIN',
            'pageCategoryTranslate t',
            self::tableName().'.id = t.category_id');
        $query->andFilterWhere(['like', 't.name', $this->name]);

        return $dataProvider;
    }

    public function behaviors()
    {
        $treeBehaviors = $this->treeBehaviors();

        $multilingualBehavior = [
            'ml' => [
                'class' => MultilingualBehavior::className(),
                'languages' =>Language::getAllLanguages('local'),
                'dynamicLangClass' => false,
                'langClassName' => CategoryTranslate::className(),
                'defaultLanguage' => Language::getDefaultLang()->url,
                'langForeignKey' => 'object_id',
                'attributes' => [
                    'name',
                    'description',
                    'content',

                ]
            ],
        ];
        return array_merge($multilingualBehavior,$treeBehaviors);
    }

    public static function find()
    {
        $query = new CategoryQuery(get_called_class());
        $query->localized();
        return $query;
    }

    public function beforeSave($insert)
    {
        TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);

        if($this->isNewRecord){
            $this->date_created = date('Y-m-d',time());
            $this->disabled = 0;
        }

        if($model = Category::find()->where(['slug'=>$this->slug])->one()){
            if($model->id != $this->id){
                $this->slug = $this->slug.'_'.time();
            }
        }

        return parent::beforeSave($insert);
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_ACTIVE   => Yii::t('app','Active'),
            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
        ];

        return $label_status[$status];
    }

    public function getLocation() {

        if(trim($this->lat) != '' AND trim($this->lon) != '')
            return $this->lat.','.$this->lon;
        else
            return false;
    }

    public function getImages()
    {
        return $this->hasMany(CategoryImages::className(), ['object_id' => 'id'])->orderBy(['sort'=>SORT_ASC]);
    }

    public function getMainImage()
    {
        return $this->hasOne(CategoryImages::className(), ['object_id' => 'id'])->where('main = 1');
    }

    public function beforeDelete()
    {
        if (parent::beforeDelete()) {

            //$images = Category::find()->where('id ='.$this->id)->with('images')->one()->images;

            //foreach($images as $image)
            //    $image->delete();

            return true;
        } else {
            return false;
        }
    }

    public function afterDelete() {
        parent::afterDelete();
        TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
     }

    public static function getTreeArray($parent_id = 1, $dataList = false) {

        if($dataList)
           $cacheKey = 'treeArrayDataList_'.$parent_id.Yii::$app->language.$dataList;
        else
           $cacheKey = 'treeArray_'.$parent_id.Yii::$app->language.$dataList;

        $result = Yii::$app->cache->get($cacheKey);

        if(!$result) {

            $category = Category::find()->where('id = '.$parent_id)->one();
            if($dataList)
                $result = self::getArrayModelDataList($category->children(1)->all());
            else
                $result = self::getArrayModel($category->children(1)->all());
            Yii::$app->cache->set(
                $cacheKey,
                $result,
                86400,
                new TagDependency([
                    'tags' => [
                        ActiveRecordHelper::getCommonTag(Category::className())
                    ]
                ])
            );
        }
        return $result;
    }

    public static function getArrayModel($models) {

        $result = [];

        foreach($models as $model) {

            if($children = $model->children(1)->all())
                $children = self::getArrayModel($model->children(1)->all());
            else
                $children = 0;
            $result[] = [
                'id'       => $model->id,
                'lvl'      => $model->lvl,
                'name'     => $model->name,
                'children' => $children,
            ];
        }
        return $result;
    }

    public static function getLevelDash($lvl) {

        $dash = '';
        for($i = 0; $i < $lvl; $i++)
            $dash.='-';

        return $dash;
    }

    public static function getListData() {

        $cacheKey = 'MedCategoryListData'.Yii::$app->language;
        $result = Yii::$app->cache->get($cacheKey);
        if(!$result) {
            $result = ArrayHelper::map(Category::find()->nonRoot()->all(),'id','name');
            Yii::$app->cache->set(
                $cacheKey,
                $result,
                86400,
                new TagDependency([
                    'tags' => [
                        ActiveRecordHelper::getCommonTag(Category::className())
                    ]
                ])
            );
            return $result;
        }

        return $result;
    }

    public static function getArrayModelChild ($children,$parent = false) {

        $result = [];
        foreach($children as $model) {
            if($child = $model->children(1)->all()) {
               $child = self::getArrayModelChild($model->children()->all(),$model);
               $result = array_merge ($result , $child);
            }else{
                    $result[] = [
                                    'id'       => $model->id,
                                    'name'     => $model->name,
                                    'parent'   => [
                                        'id'=>$parent->id,
                                        'name'=>$parent->name
                                    ],
                                ];
                }
        }
        return $result;
    }

    public function getProducts(){
        //$products = Page::find()->where(['catalog_category_id'=>$this->id])->all();
        $products = Page::find()->where(['catalog_category_id'=>$this->id])->orderBy(['slug' => SORT_ASC])->all();
        return $products;
    }

    public function getType() {
        return $this->hasOne(CategoryType::className(), ['id' => 'type']);
    }

}
