<?php

namespace app\modules\catalog\models;

use Yii;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use yii\db\ActiveRecord;
use app\modules\page\models\Page;
use devgroup\TagDependencyHelper\ActiveRecordHelper;

class CategoryType extends ActiveRecord {

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;


    public static function tableName() {
        return '{{%category_type}}';
    }

    public function rules() {
        return [
            [['page_id'], 'required'],
            [['id','status'], 'safe'],
        ];
    }

    public function attributeLabels() {
        return [
            'id'           => 'ID',
            'status'       => Yii::t('app', 'Status'),
            'page_id'      => Yii::t('app', 'Page'),
        ];
    }

    public function search($params) {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 30,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->andFilterWhere([self::tableName().'.page_id' => $this->sms_id]);

        return $dataProvider;
    }

    public function beforeSave($insert) {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        return parent::beforeSave($insert);
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_ACTIVE   => Yii::t('app','Active'),
            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
        ];

        return $label_status[$status];
    }

    public function getPage() {
        return $this->hasOne(Page::className(), ['id' => 'page_id']);
    }

    public function getListData() {

        $categoryTypes = CategoryType::find()->all();
        $data          = [];

        foreach($categoryTypes as $type)
            $data[$type->id] = $type->getPage()->one()->name;

        return $data;

    }


}
