<?php

use yii\helpers\Html;
use app\backend\components\ActionColumn;
use kartik\dynagrid\DynaGrid;
use kartik\icons\Icon;
use app\modules\catalog\models\CategoryType;
use app\modules\page\models\Page;
use kartik\grid\GridView;


$this->title = Yii::t('app', 'Category Type');
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="row">
        <div class="col-sm-12">
        <?=DynaGrid::widget([
            'options' => [
                'id' => 'backend-category-type',
            ],
            'columns' => [
                'id',
                [
                    'class' => 'kartik\grid\DataColumn',
                    'attribute' => 'page_id',
                    'value'=>function($data){
                        return $data->getPage()->one()->name;
                    },
                    'filterType'=>GridView::FILTER_SELECT2,
                    'filter'=>Page::getListData(),
                    'filterWidgetOptions'=>[
                        'pluginOptions' => ['allowClear' => true],
                    ],
                    'filterInputOptions' => ['placeholder' => Yii::t('app','Page'),  'id'=>'category-type-page_id'],
                    'format'=>'raw',
                ],

                [
                    'class' => \kartik\grid\EditableColumn::className(),
                    'attribute' => 'status',
                    'options' => [
                      //  'width' => '100px',
                     ],
                    'editableOptions' => [
                        'data' => [
                                    CategoryType::STATUS_INACTIVE=>CategoryType::getStatusLabel(CategoryType::STATUS_INACTIVE),
                                    CategoryType::STATUS_ACTIVE=>CategoryType::getStatusLabel(CategoryType::STATUS_ACTIVE),
                                  ],
                        'inputType' => 'dropDownList',
                        'placement' => 'left',
                        'formOptions' => [
                            'action' => 'update-country',
                         ],

                    ],
                    'format' => 'raw',
                    'filter'=>[
                                CategoryType::STATUS_INACTIVE=>CategoryType::getStatusLabel(CategoryType::STATUS_INACTIVE),
                                CategoryType::STATUS_ACTIVE=>CategoryType::getStatusLabel(CategoryType::STATUS_ACTIVE),
                              ],
                     'value' => function ($data) {
                        if ($data === null || $data->status === null) {
                            return null;
                        }
                        if ($data->status == 0) {
                            $label_class = 'label-default';
                            $value = CategoryType::getStatusLabel(CategoryType::STATUS_INACTIVE);
                        }elseif ($data->status == 1) {
                            $label_class = 'label-success';
                            $value = CategoryType::getStatusLabel(CategoryType::STATUS_ACTIVE);
                        }
                        return Html::tag(
                            'span',
                            Yii::t('app', $value),
                            ['class' => "label $label_class"]
                        );
                    },

                ],

                [
                    'class' => ActionColumn::className(),
                    'options' => [
                        'width' => '95px',
                    ],
                    'buttons' => [
                        [
                            'url' => 'edit',
                            'icon' => 'pencil',
                            'class' => 'btn-primary',
                            'label' => Yii::t('app', 'Edit'),
                        ],
                        [
                            'url' => 'delete',
                            'icon' => 'trash-o',
                            'class' => 'btn-danger',
                            'label' => Yii::t('app', 'Delete'),
                            'options' => [
                                'data-action' => 'delete',
                            ],
                        ],
                    ],
                ],
            ],
            'theme' => 'panel-default',
            'gridOptions'=>[
                'dataProvider' => $dataProvider,
                'filterModel'  => $searchModel,
                'hover' => true,
                'panel' => [

                    'heading' => Html::tag('h3', $this->title, ['class' => 'panel-title']),
                    'after' => Html::a(
                            Icon::show('plus') . Yii::t('app', 'Add'),
                            ['/catalog/backend-category-type/edit', 'returnUrl' => \app\backend\components\Helper::getReturnUrl()],
                            ['class' => 'btn btn-success']
                        ),
                ],

            ]
        ]);
        ?>

        </div>
</div>
