<?php

use yii\helpers\Html;
use app\backend\components\ActionColumn;
use kartik\dynagrid\DynaGrid;
use kartik\icons\Icon;
use \devgroup\JsTreeWidget\ContextMenuHelper;
use \app\backend\components\Helper;
use kartik\tree\TreeView;
use app\modules\catalog\models\CategoryType;
use app\modules\page\models\PageCategory;
use kartik\grid\GridView;


$this->title = Yii::t('app', 'Category');
$this->params['breadcrumbs'][] = $this->title;

?>
<div class="row">
        <div class="col-sm-8">
        <?=DynaGrid::widget([
            'options' => [
                'id' => 'backend-catalog-index',
            ],
            'columns' => [
                'id',
                'name',
                [
                    'class' => 'kartik\grid\DataColumn',
                    'attribute' => 'type',
                    'value'=>function($data){
                        if($type = $data->getType()->one())
                        return $type->getPage()->one()->name;
                    },
                    'filterType'=>GridView::FILTER_SELECT2,
                    'filter'=>PageCategory::getListData(),
                    'filterWidgetOptions'=>[
                        'pluginOptions' => ['allowClear' => true],
                    ],
                    'filterInputOptions' => ['placeholder' => Yii::t('app','Type'),  'id'=>'category-type-page_id'],
                    'format'=>'raw',
                ],
                'sort_order',
                [
                    'class' => ActionColumn::className(),
                    'options' => [
                        'width' => '95px',
                    ],
                    'buttons' => [
                        [
                            'url' => 'edit',
                            'icon' => 'pencil',
                            'class' => 'btn-primary',
                            'label' => Yii::t('app', 'Edit'),
                        ],
                        [
                            'url' => 'delete',
                            'icon' => 'trash-o',
                            'class' => 'btn-danger',
                            'label' => Yii::t('app', 'Delete'),
                            'options' => [
                                'data-action' => 'delete',
                            ],
                        ],
                    ],
                ],
            ],
            'theme' => 'panel-default',
            'gridOptions'=>[
                'dataProvider' => $dataProvider,
                'filterModel'  => $searchModel,
                'hover' => true,
                'panel' => [

                    'heading' => Html::tag('h3', $this->title, ['class' => 'panel-title']),
                    'after' => Html::a(
                            Icon::show('plus') . Yii::t('app', 'Add'),
                            ['/catalog/backend-category/edit', 'returnUrl' => \app\backend\components\Helper::getReturnUrl()],
                            ['class' => 'btn btn-success']
                        ),
                ],

            ]
        ]);
        ?>

        </div>

        <div class="col-sm-4">
            <?=  \tree\JsTreeWidget\TreeWidget ::widget([
                'treeDataRoute' => ['getTree'],
                'className' => 'app\\\\modules\\\\catalog\\\\models\\\\Category',
                'options'=>
                    [
                        'core'=>[
                                    "multiple" => false,
                                ],
                    ],
                'changeParentAction' => '/treemanager/node/move',
                'doubleClickAction' => ContextMenuHelper::actionUrl(
                    ['edit', 'returnUrl' => Helper::getReturnUrl()],
                    [
                        'id' => 'id'
                    ]
                ),
                'contextMenuItems' => [
                    'edit' => [
                        'label' => Yii::t('app','Edit'),
                        'icon' => 'fa fa-pencil',
                        'action' => ContextMenuHelper::actionUrl(
                            ['/catalog/backend-category/edit', 'returnUrl' => Helper::getReturnUrl()],
                            [
                                'id' => 'id'
                            ]
                        ),
                    ],
                    'open' => [
                        'label' => Yii::t('app','Open'),
                        'icon' => 'fa fa-folder-open',
                        'action' => ContextMenuHelper::actionUrl(
                            ['/catalog/backend-category/index'],
                            [
                                'parent_id' => 'id',
                            ]
                        ),
                    ],
                    'create' => [
                        'label' => Yii::t('app','Create'),
                        'icon' => 'fa fa-plus-circle',
                        'action' => ContextMenuHelper::actionUrl(
                            ['/catalog/backend-category/edit', 'returnUrl' => Helper::getReturnUrl()],
                            [
                                'parent_id' => 'id',
                            ]
                        ),
                    ],
                    'delete' => [
                        'label' => Yii::t('app','Delete'),
                        'icon' => 'fa fa-trash-o',
                        'action' => new \yii\web\JsExpression(
                            "function(node) {
                                        jQuery('#delete-confirmation')
                                            .attr('data-url', '/catalog/backend-category/delete?id=' + jQuery(node.reference[0]).data('id'))
                                            .attr('data-items', '')
                                            .modal('show');
                                        return true;
                                    }"
                        ),
                    ],
                ],
            ]);
            ?>

        </div>
</div>
