<?php

namespace app\modules\core\models;

use Yii;
use yii\web\UploadedFile;
use yii\caching\TagDependency;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\imagine\Image;
use Imagine\Image\ManipulatorInterface;
use yii\helpers\ArrayHelper;


/**
 * This is the model class for table "language".
 *
 * @property integer $id
 * @property string $url
 * @property string $local
 * @property string $name
 * @property integer $default
 * @property integer $date_update
 * @property integer $date_create
 */
class Language extends \yii\db\ActiveRecord
{
    const MATERIKI_1 = 1;
    const MATERIKI_2 = 2;
    const MATERIKI_3 = 3;
    const MATERIKI_4 = 4;
    const MATERIKI_5 = 5;
    const MATERIKI_6 = 6;

    static $current = null;

    public $uploadDir = '/upload/language/';
    public $thumbnailDir = '/thumbnail/language';

    public static function tableName()
    {
        return 'language';
    }

    public function rules()
    {
        return [
            [['url', 'local', 'name','materiki'], 'required'],
            [['default', 'date_update', 'date_create'], 'integer'],
            [['url', 'local', 'name'], 'string', 'max' => 255],
            [['flag'], 'safe']
        ];
    }

    public function attributeLabels()
    {
        return [
            'id'          => 'ID',
            'url'         => 'Url',
            'local'       => 'Local',
            'name'        => 'Name',
            'default'     => 'Default',
            'date_update' => 'Date Update',
            'date_create' => 'Date Create',
            'materiki'    => 'Materiki',
            'flag'        => 'Flag',
        ];
    }
    
    public function behaviors()
    {
        return [
            'timestamp' => [
                'class' => 'yii\behaviors\TimestampBehavior',
                'attributes' => [
                    \yii\db\ActiveRecord::EVENT_BEFORE_INSERT => ['date_create', 'date_update'],
                    \yii\db\ActiveRecord::EVENT_BEFORE_UPDATE => ['date_update'],
                ],
            ],
        ];
    }

    public function beforeSave($insert)
    {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        return parent::beforeSave($insert);
    }

    public static function getCurrent()
    {
        if( self::$current === null ){
            self::$current = self::getDefaultLang();
        }
        return self::$current;
    }

    public static function setCurrent($url = null)
    {
        $language = self::getLangByUrl($url);
        self::$current = ($language === null) ? self::getDefaultLang() : $language;
        Yii::$app->language = self::$current->local;
    }

    public static function getDefaultLang()
    {

        $url_list = explode('/', Yii::$app->request->getUrl());
        $lang_url = isset($url_list[1]) ? $url_list[1] : null;
        $default = Language::find()->where(['url'=>$lang_url])->one();

        return $default;

        $cacheKey = 'Default-Language';
        $default = Yii::$app->cache->get($cacheKey);
        if(!$default) {


            //$default = Language::find()->where('url = :url', [':url' => self::getLanguage()])->one();
            Yii::$app->cache->set(
                $cacheKey,
                $default,
                86400,
                new TagDependency([
                    'tags' => [
                        ActiveRecordHelper::getCommonTag(self::className())
                    ]
                ])
            );
        }
        return $default;
    }

    public static function getAllLanguages($type)
    {
        $cacheKey = 'All-Languages_'.$type;

        $languages = Yii::$app->cache->get($cacheKey);

        if(!$languages) {
            foreach(Language::find()->all() as $lang){
                $languages[] = $lang->$type;
            }
            Yii::$app->cache->set(
                $cacheKey,
                $languages,
                86400,
                new TagDependency([
                    'tags' => [
                        ActiveRecordHelper::getCommonTag(self::className())
                    ]
                ])
            );

        }
        return $languages;
    }
    
    public static function getLanguages()
    {
        $arry = array();
        foreach(Language::find()->where('`default` = :default', [':default' => 0])->all() as $lang)
        {
            $arry[] = $lang->local;
        }
        return $arry;
    }
    
    public static function getLanguagesForForm()
    {
        $arry = array();
        foreach(Language::find()->all() as $lang)
        {
            if(Language::getDefaultLang()->url == $lang->url)
                $arry[] = "";
            else
                $arry[] = "_".$lang->url;
        }
        return $arry;
    }
    
    public static function getLanguageForForm()
    {
        if(Language::getDefaultLang()->url == substr(Yii::$app->language,0,2))
                $prefix = "";
            else
                $prefix = "_".substr(Yii::$app->language,0,2);
        
        return $prefix;
    }

    public static function getLanguage() {
        return substr(Yii::$app->language,0,2);
    }

    public  static function getLangByUrl($url = null)
    {
        if ($url === null) {
            return null;
        } else {
            $language = Language::find()->where('url = :url', [':url' => $url])->one();
            if ( $language === null ) {
                return null;
            }else{
                return $language;
            }
        }
    }
    
    public static function getActiveLanguage($default = false)
    {
        if(!$default){
            if(Language::getDefaultLang()->local != Yii::$app->language)
                return '/'.substr(Yii::$app->language,0,2);
            else
                return '/';    
        }else
            return substr(Yii::$app->language,0,2);
    }

    public static function getUrl() {
        return substr(Yii::$app->language,0,2);
    }

    public static function getMaterikiList(){
       return [
            Language::MATERIKI_1 => Yii::t('app','Asia'),
            Language::MATERIKI_2 => Yii::t('app','Europe'),
            Language::MATERIKI_3 => Yii::t('app','Africa'),
            Language::MATERIKI_4 => Yii::t('app','Australia'),
            Language::MATERIKI_5 => Yii::t('app','North America'),
            Language::MATERIKI_6 => Yii::t('app','South America'),
        ];
    }

    public function uploadFile() {

        $file =  UploadedFile::getInstancesByName('Language');

        $file = $file[0];

        if ($file) {
            $prefx = rand(100,999).'_'.time();
            $fileName  = $this->id.'_'.$prefx.'.'.$file->extension;
            if(!file_exists(Yii::getAlias('@webroot'.$this->uploadDir)))
                mkdir(Yii::getAlias('@webroot'.$this->uploadDir),0777);

            $uploadDir = Yii::getAlias('@webroot'.$this->uploadDir);
            $fn = $uploadDir . $fileName;
            $file->saveAs($fn);
            return str_replace(Yii::getAlias('@webroot'), '', $uploadDir).$fileName;
        }else
            return false;
    }

    public function  getThumbnail($width,$height) {
        $flag = $width."-".$height."_".strtolower(substr(strrchr($this->flag,"/"),1));

        $file = Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$flag);

        if(file_exists($file)) {
            return $this->thumbnailDir.'/'.$flag;
        }else {

            if(!file_exists(Yii::getAlias('@webroot'.$this->thumbnailDir)))
                mkdir(Yii::getAlias('@webroot'.$this->thumbnailDir),0777);

            if(trim($this->flag != "") AND file_exists(Yii::getAlias('@webroot').$this->flag)){

                $thumb =  Image::thumbnail('@webroot'.$this->flag, $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                    ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_".strtolower(substr(strrchr($this->flag,"/"),1))), ['quality' => 100]);
                return $this->thumbnailDir.'/'.$flag;

            }else{

                if(!file_exists(Yii::getAlias('@webroot').$this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg')){
                    $thumb =  Image::thumbnail('images/not_foto.jpg', $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                        ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_not_foto.jpg"), ['quality' => 100]);
                    return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';
                }else
                    return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';

            }
        }
    }

    public function deleteImage() {
        $fileDir = Yii::getAlias('@webroot/'.$this->oldAttributes['flag']);
        if(file_exists($fileDir) AND $this->oldAttributes['flag'] != '') {
            unlink($fileDir);
            return true;
        }else
            return false;
    }

    public static function getListData() {
        return ArrayHelper::map(Language::find()->all(),'id','name');
    }
}
