<?php
namespace app\modules\core\widgets\includefile;

use \Yii;
use yii\base\Widget;
use yii\helpers\Url;
use yii\helpers\Html;
use yii\widgets\ActiveForm;
use froala\froalaeditor\FroalaEditorWidget;
use app\modules\core\models\Language;
use yii\web\ServerErrorHttpException;


class IncludeFile extends Widget
{
    public $path= '@webroot/includeFiles';
    public $file;
    public $filePath;
    public $content;
    public $id;
    public $width = '50px';
    public $height = '20px';


    public function init()
    {
        parent::init();

        $this->id = "includefile_".rand(1,1000).rand(1,1000);

        $path = Yii::getAlias($this->path).'/'.Language::getUrl();

        if( !file_exists($path) )
        {
            mkdir($path);
        }
        $this->filePath = $path.DIRECTORY_SEPARATOR.$this->file;
        if( file_exists($this->filePath) )$this->content = file_get_contents($this->filePath);
    }

    public function run()
    {
        $this->registerAssets();

        $this->beginAdminTool();

        $this->render();

        $this->endAdminTool();
    }


    public function render()
    {
        $path = Yii::getAlias($this->path).'/'.Language::getUrl();
        if( is_dir($path) )
        {
            $this->filePath = $path.DIRECTORY_SEPARATOR.$this->file;


            if( file_exists($this->filePath) )
            {
                ob_start();
                include($this->filePath);
                $this->content = ob_get_contents();
                ob_end_flush();
            }
            else
            {
                file_put_contents($this->filePath,'');
            }

            if( !is_writable($this->filePath) )
            {
                throw new ServerErrorHttpException('IncludeFile - Error: Couldn\'t Writable file '.$this->filePath);
            }
        }
    }


    public function beginAdminTool()
    {
        if(Yii::$app->user->can('administrate'))
        {
            if(!$this->content)
                $style = "style='width: ".$this->width."; height: ".$this->height."; border: 2px solid red'";
            else
                $style = "";

            echo "<div class='bb-admin-tool' ".$style.">
                    <a class='e-edit-btn icon-pencil j-editFile'
                        data-dialog-id='dialog_".$this->id."'
                        data-form-id='form_".$this->id."'
                        data-content-id='content_".$this->id."'
                        data-url='".Url::toRoute('/core/ajax/save-file')."'
                    ><i class='fa fa-pencil-square'></i></a> ";
        }
    }


    public function endAdminTool()
    {
        if(Yii::$app->user->can('administrate'))
        {
            echo "</div>";
            echo "<div id='dialog_".$this->id."' style='display:none;'>";

            $form = ActiveForm::begin(
                [
                    'action'=>[
                        Url::toRoute('/core/ajax/save-file'),

                    ],
                    'id' => "form_".$this->id
                ]
            );


            echo FroalaEditorWidget::widget([
                'name' => 'content',
                'value' => file_get_contents($this->filePath),
                'options'=>[// html attributes
                    'id'=>'content_'.$this->id
                ],
                'clientOptions'=>[
                    'toolbarInline'=> false,
                    'theme' =>'royal',//optional: dark, red, gray, royal
                    'language'=>'en_gb' // optional: ar, bs, cs, da, de, en_ca, en_gb, en_us ...
                ]
            ]);

            echo Html::hiddenInput('FileName',$this->filePath);
            ActiveForm::end();
            echo "</div>";
        }
    }
    /**
     * Register slider-specific assets(js, css, etc.)
     * @return void
     */
    public function registerAssets()
    {
        IncludeFileAsset::register($this->getView());
    }


}