<?php

namespace app\modules\notification\models;

use Yii;
use yii\helpers\ArrayHelper;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use app\components\MedBaseActiveRecord;
use devgroup\TagDependencyHelper\ActiveRecordHelper;

class Notification extends MedBaseActiveRecord {

    const TYPE_PAGE            = 'page';
    const TYPE_QUESTION        = 'question';
    const TYPE_RECEPTION       = 'reception';
    const TYPE_MED_HISTORY     = 'medHistory';
    const TYPE_LINL            = 'link';

    const MESSAGE_TYPE_SUCCESS = 'success';
    const MESSAGE_TYPE_DANGER  = 'danger';
    const MESSAGE_TYPE_WARNING = 'warning';
    const MESSAGE_TYPE_INFO    = 'info';

    public static function tableName() {
        return '{{%notification}}';
    }

    public function rules() {
        return [
            [['user_id','text','type','message_type','object_id'], 'required'],
            [['id','date_created','status','view','data'], 'safe'],
        ];
    }

    public function attributeLabels() {
        return [
            'id'           => 'ID',
            'status'       => Yii::t('app', 'Status'),
            'user_id'      => Yii::t('app', 'User'),
            'text'         => Yii::t('app', 'Text'),
            'view'         => Yii::t('app', 'View'),
            'type'         => Yii::t('app', 'Type'),
            'message_type' => Yii::t('app', 'Message type'),
            'object_id'    => Yii::t('app', 'Object'),
            'date_created' => Yii::t('app', 'Date created'),
            'data'         => Yii::t('app', 'data'),
        ];
    }

    public function search($params) {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 30,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->andFilterWhere(['like', self::tableName().'.date_created', $this->date_created]);

        return $dataProvider;
    }

    public function beforeSave($insert) {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        if($this->isNewRecord){
            $this->date_created = date("Y-m-d H:i",time());
            $this->view         = 0;
            $this->status       = 0;
        }
        return parent::beforeSave($insert);
    }

    public function sendNotification($text,$user_id,$type,$message_type,$object_id,$data=null){

        $notification               = new Notification();
        $notification->user_id      = $user_id;
        $notification->text         = $text;
        $notification->type         = $type;
        $notification->message_type = $message_type;
        $notification->object_id    = $object_id;
        $notification->data         = $data;

        if($notification->save())
            return true;
        else
            return false;
    }

}
