<?php

/**
 * @var $dataProvider \yii\data\ActiveDataProvider
 * @var $searchModel \app\components\SearchModel
 * @var $this \yii\web\View
 */

use app\backend\components\ActionColumn;
use kartik\dynagrid\DynaGrid;
use kartik\helpers\Html;
use kartik\icons\Icon;
use kartik\editable\Editable;
use kartik\popover\PopoverX;
use app\modules\order\models\VacancyOrders;
use app\modules\page\models\Page;
use kartik\grid\GridView;

$this->title = Yii::t('app', 'Vacancy Orders');
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="vacancy-order-index">
    <?=DynaGrid::widget([
            'options' => [
                'id' => 'vacancy-order-grid',
            ],
            'columns' => [
                [
                    'class' => \kartik\grid\CheckboxColumn::className(),
                    'options' => [
                        'width' => '10px',
                    ],
                ],
                [
                    'class' => 'yii\grid\DataColumn',
                    'attribute' => 'id',
                    'options' => [
                        'width' => '70px',
                     ],
                ],
                [
                    'class' => 'kartik\grid\DataColumn',
                    'attribute' => 'vacancy_id',
                    'value'=>function($data){
                        return $data->getVacancy()->one()->name;
                    },
                    'filterType'=>GridView::FILTER_SELECT2,
                    'filter'=>Page::getListData(),
                    'filterWidgetOptions'=>[
                        'pluginOptions' => ['allowClear' => true],
                    ],
                    'filterInputOptions' => ['placeholder' => Yii::t('app','Vacancy'),  'id'=>'vacancy-order-vacancy_id'],
                    'format'=>'raw',
                ],             
                'first_name',
                'last_name',
                'phone',
                'email',
                'created:datetime',
                [
                    'attribute'=>'file_name',
                    'format'=>'raw',
                    'value' => function($data)
                    {
                    return
                    Html::a('<i class="fa fa-download" aria-hidden="true"></i>', ['backend-vacancy-order/download', 'id' => $data->id],['class' => '']);
                    }
                ],
                [
                    'class' => ActionColumn::className(),
                    'options' => [
                        'width' => '95px',
                    ],
                    'buttons' => [
                        [
                            'url' => 'view',
                            'icon' => 'search',
                            'class' => 'btn-primary',
                            'label' => Yii::t('app', 'View'),

                        ],
                        [
                            'url' => 'delete',
                            'icon' => 'trash-o',
                            'class' => 'btn-danger',
                            'options' => [
                                'data-action' => 'delete',
                            ],
                            'label' => Yii::t('app', 'Delete'),
                        ],
                    ],
                ],
            ],
            'theme' => 'panel-default',
            'gridOptions'=>[
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'hover' => true,
                /*'panel' => [
                    'heading' => Html::tag('h3', $this->title, ['class' => 'panel-title']),
                    'after' => Html::a(
                        Icon::show('plus') . Yii::t('app', 'Add'),
                        ['/order/backend-vacancy-order/update'],
                        ['class' => 'btn btn-success']
                    ) . \app\backend\widgets\RemoveAllButton::widget([
                        'url' => '/order/backend-vacancy-order/remove-all',
                        'gridSelector' => '.grid-view',
                        'htmlOptions' => [
                            'class' => 'btn btn-danger pull-right'
                        ],
                    ]),

                ],*/
            ]
        ]);
    ?>
</div>