<?php

namespace app\modules\page\controllers;

use app\components\Controller;
use app\modules\page\models\Page;
use app\models\Search;
use app\modules\seo\behaviors\MetaBehavior;
use app\traits\LoadModel;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use Yii;
use yii\caching\TagDependency;
use yii\data\Pagination;
use yii\db\ActiveQuery;
use yii\web\ForbiddenHttpException;
use yii\web\NotFoundHttpException;
use yii\web\Response;
use yii\helpers\Url;
use yii\data\ActiveDataProvider;
use app\modules\page\models\PageCategory;
use app\modules\user\models\User;
use app\components\Helper;
use yii\web\UploadedFile;
use app\models\OrderForm;
use app\modules\order\models\ProductOrders;
use app\modules\order\models\VacancyOrders;
use app\models\UploadForm;



class PageController extends Controller
{
    use LoadModel;

    public function behaviors()
    {
    return [
        'seo' => [
            'class' => MetaBehavior::className(),
            'index' => $this->defaultAction,
        ],
    ];
    }

    public function actionIndex() {
        return $this->render('index');
    }

    public function actionNewsList() {

        $request        = Yii::$app->request;

        $categoryClinic = PageCategory::find()->where(['slug'=>'clinic'])->one();
        $categoryPages  = PageCategory::find()->where(['slug'=>'pages'])->one();
        $categoryNews   = PageCategory::find()->where(['slug'=>'news'])->one();
        $pageQuery = Page::find()
                           ->where( [
                                'published'=>1,
                                'category_id'=>[$categoryClinic->id,$categoryNews->id]
                               ])
                           ->orderBy(['date_added'=>SORT_DESC]);

        if($request->get('created')){
            $pageQuery->andWhere(" date(date_added) = '".$request->get('created')."'");
        }

        return $this->render('news-list',
               [
                'pageQuery'=>$pageQuery
               ]);
    }

    public function actionShow($url) {
        if (null === $model = Page::find()->where(['slug'=>$url])->one()) {
            throw new NotFoundHttpException;
        }

        if (!empty($model->meta_description)) {
            $this->view->registerMetaTag(
                [
                    'name' => 'description',
                    'content' => $model->meta_description,
                ],
                'meta_description'
            );
        }

        $this->view->title = $model->title;
        if (!empty($model->h1)) {
            $this->view->blocks['h1'] = $model->h1;
        }
        $this->view->blocks['content'] = $model->content;
        $this->view->blocks['announce'] = $model->announce;

        return $this->render(
            $this->computeViewFile($model, 'show'),
            [
                'model' => $model,
                'breadcrumbs' => $this->buildBreadcrumbsArray($model)
            ]
        );
    }

    public function actionDetail($url)  {

        $model = Page::find()->where(['slug'=>$url])->one();

        return $this->render(
            'detail',
            [
                'model'       => $model,
            ]
        );
    }

    public function actionList($id) {
        if (null === $model = Page::find()->where(['id'=>$id])->multilingual()->one()) {
            throw new NotFoundHttpException;
        }
        if (!empty($model->meta_description)) {
            $this->view->registerMetaTag(
                [
                    'name' => 'description',
                    'content' => $model->meta_description,
                ],
                'meta_description'
            );
        }

        $cacheKey = 'PagesList:'.$model->id;

        // query that needed for pages retrieve and pagination
        $children = Page::find()
            ->where(['parent_id' => $model->id, 'published' => 1])
            ->orderBy('date_added DESC, sort_order')
            ->with('images');

        // count all pages
        $count = Yii::$app->cache->get($cacheKey.';count');
        if ($count === false) {
            $countQuery = clone $children;
            $count = $countQuery->count();
            Yii::$app->cache->set($cacheKey.';count', $count, 86400, new TagDependency([
                'tags' => [
                    ActiveRecordHelper::getCommonTag(Page::className())
                ]
            ]));
        }

        $pages = new Pagination(
            [
                'defaultPageSize' => $this->module->pagesPerList,
                'forcePageParam' => false,
                'pageSizeLimit' => [
                    $this->module->minPagesPerList,
                    $this->module->maxPagesPerList
                ],
                'totalCount' => $count,
            ]
        );

        // append current page number to cache key
        $cacheKey .= ';page:' . $pages->page;

        $childrenModels = Yii::$app->cache->get($cacheKey);
        if ($childrenModels === false) {

            /** @var ActiveQuery $children */

            $children = $children->offset($pages->offset)
                ->limit($pages->limit)
                ->all();
            Yii::$app->cache->set($cacheKey, $children, 86400, new TagDependency([
                'tags' => [
                    ActiveRecordHelper::getCommonTag(Page::className())
                ]
            ]));
        } else {
            $children = $childrenModels;
        }

        $this->view->title = $model->title;
        if (!empty($model->h1)) {
            $this->view->blocks['h1'] = $model->h1;
        }
        $this->view->blocks['content'] = $model->content;
        $this->view->blocks['announce'] = $model->announce;

        return $this->render(
            $this->computeViewFile($model, 'list'),
            [
                'model' => $model,
                'children' => $children,
                'pages' => $pages,
                'breadcrumbs' => $this->buildBreadcrumbsArray($model),
            ]
        );
    }

    public function actionSearch()  {
        if(Yii::$app->request->get('Search'))
        {
           $model = Page::find()->where()->multilingual();

           $model->join('LEFT JOIN',
                           'pageTranslate pt',
                           'page.id = pt.page_id');

           foreach (['name', 'content', 'title', 'h1'] as $attribute) {
                $model->orWhere(['like','pt.'.$attribute, Yii::$app->request->get('Search')]);
            }
           $model->andWhere(['pt.language'=>substr(Yii::$app->language,0,2)]);
           $dataProvider = new ActiveDataProvider([
                'query' => $model,
                'pagination' =>
                    [
                       'pageSize' => 20,
                    ],
            ]);

        }else
        $dataProvider  = false;
        return $this->render(
            'search',
            [
              'dataProvider'=>$dataProvider
            ]
        );
    }

    public function actionAutoCompleteSearch($term) {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $query = Page::find()
            ->select(['*'])
            ->join('LEFT JOIN',
                       'pageTranslate pt',
                       'page.id = pt.page_id');
        // ->orderBy(['sort_order' => SORT_ASC, 'id' => SORT_DESC]);
        foreach (['name', 'content', 'title', 'h1'] as $attribute) {
            $query->orWhere(['like','pt.'.$attribute, $term]);
        }
        $query->andWhere(['pt.language'=>substr(Yii::$app->language,0,2)]);
        $pages = $query->limit(Yii::$app->getModule('core')->autoCompleteResultsCount)->all();
        $result = [];

        foreach ($pages as $page) {
            /** @var Product $page */
            $result[] = [
                'id' => $page->id,
                'name' => $page->name,
                'url' => Url::toRoute(['/'.$page->slug],true),
            ];
        }
        return $result;
    }

    private function buildBreadcrumbsArray($model) {
        if ($model === null || $model->id === 1) {
            return [];
        }

        // init
        $breadcrumbs = [];
        $crumbs[$model->slug] = $model->breadcrumbs_label;

        // get basic data
        $parent = Page::findById($model->parent_id);
        // if parent exists and not a main page
        while ($parent !== null && $parent->id != 1) {
            $crumbs[$parent->slug] = $parent->breadcrumbs_label;
            $parent = $parent->parent;
        }

        // build array for widget
        $url = '';
        $crumbs = array_reverse($crumbs, true);
        foreach ($crumbs as $slug => $label) {
            $url .= '/' . $slug;
            $breadcrumbs[] = [
                'label' => (string) $label,
                'url' => $url
            ];
        }
        unset($breadcrumbs[count($breadcrumbs) - 1]['url']); // last item is not a link

        return $breadcrumbs;
    }

    /*public function actionAjaxModal($url)  {

        $model = Page::find()->where(['slug'=>$url])->one();

        if(Yii::$app->request->isAjax){
            return $this->renderAjax('ajax-modal',
                [
                    'model'       => $model,
                ]
            );
        }

        return $this->render('ajax-modal',
            [
                'model'       => $model,
            ]
        );
    }*/
    
    /*yangi*/
    public function actionAjaxModal($url)  {

        $model = Page::find()->where(['slug'=>$url])->one();

        /*yangi*/
        $model2 = new ProductOrders();
        if ( $model2->load(Yii::$app->request->post()) ) 
        {
            $model2->attributes = \Yii::$app->request->post('ProductOrders');

            if( $model2->validate() )            
            {
                //$model2->phone = $_POST['ProductOrders']['phone'];
                $model2->product_id = $model->id;

                $model2->save();
                // flash sobsheniya yozish Sessiyaga
                Yii::$app->session->setFlash('success', 'Новый заказ принятен');
                
                // Hammasi uspeshno yakunlanganidan keyin polyalarni tozlash
                //return $this->refresh();

                return $this->redirect(Yii::$app->request->referrer);
            }                
            // }
            // aks holda
            else
            {
                Yii::$app->session->setFlash('error', 'Ошибка при приняте заказа');
            }
        }
        /*yangi*/

        if(Yii::$app->request->isAjax){
            return $this->renderAjax('ajax-modal',
                [
                    'model'       => $model,
                    'model2'      => $model2,
                ]
            );
        }

        return $this->render('ajax-modal',
            [
                'model'       => $model,
                'model2'      => $model2,
            ]
        );
    }
    /*yangi*/

    public function actionAjaxModalType($url)  {

        $model = Page::find()->where(['slug'=>$url])->one();

        if(Yii::$app->request->isAjax){
            return $this->renderAjax('ajax-modal-type',
                [
                    'model'       => $model,
                ]
            );
        }

        return $this->render('ajax-modal-type',
            [
                'model'       => $model,
            ]
        );
    }

    public function actionAjaxModalOrderForm()  {

       $model                  = new OrderForm();

       if( Yii::$app->request->post('product') AND Yii::$app->request->post('attributesValue') ){
           $model->attributesValue = json_encode(Yii::$app->request->post('attributesValue'));
           $model->product         = json_encode(Yii::$app->request->post('product'));
       }
        if(Yii::$app->request->isAjax){

            if ($model->load(Yii::$app->request->post()) AND $model->validate()) {

                if($model->sendOrder()){
                    echo json_encode(1);
                }else{
                    echo json_encode(0);
                }

                Yii::$app->end();
            }



            return $this->renderAjax('order-form',
                [
                    'model' => $model,
                ]
            );
        }

    }
    
    /*yangi*/
    public function actionAjaxModalVacancy($url)  {

        $model = Page::find()->where(['slug'=>$url])->one();

        /*yangi*/
        $model2 = new VacancyOrders();
        if ( $model2->load(Yii::$app->request->post()) ) 
        {
            $model2->attributes = \Yii::$app->request->post('VacancyOrders');

            $model2->file_name = UploadedFile::getInstance($model2, 'file_name');
            
            if( $model2->validate() )            
            {
                $model2->vacancy_id = $model->id;
                
                $model2->save();

                if( $model2->save() )
                {
                    $model2->upload();      
                }

                Yii::$app->session->setFlash('success', 'Новая анкета принятена');
                
                return $this->redirect(Yii::$app->request->referrer);
            }                
            
            else
            {
                Yii::$app->session->setFlash('error', 'Ошибка при приняте анкеты');
            }
        }
        /*yangi*/

        if(Yii::$app->request->isAjax){
            return $this->renderAjax('ajax-modal-vacancy',
                [
                    'model'       => $model,
                    'model2'       => $model2,
                ]
            );
        }

        return $this->render('ajax-modal-vacancy',
            [
                'model'       => $model,
                'model2'       => $model2,
            ]
        );
    }
    /*yangi*/
}
