<?php

namespace app\modules\page\models;

use Yii;
use app\behaviors\Tree;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\behaviors\TimestampBehavior;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use yii\db\ActiveRecord;
use yii\db\Expression;

use app\modules\core\models\Language;
use omgdef\multilingual\MultilingualBehavior;
use omgdef\multilingual\MultilingualQuery;

use app\modules\page\models\PageTranslate;
use app\modules\page\models\PageCategory;

use app\modules\user\models\User;

use yii\imagine\Image;
use Imagine\Image\ManipulatorInterface;
use app\modules\page\models\PageImages;
use yii\helpers\ArrayHelper;
use yii\web\UploadedFile;

use app\modules\catalog\models\CategoryType;

use app\properties\HasProperties;

/**
 * This is the model class for table "page".
 * @property integer $id
 * @property integer $parent_id
 * @property string $slug
 * @property string $slug_compiled
 * @property boolean $slug_absolute
 * @property boolean $published
 * @property boolean $is_new
 * @property boolean $searchable
 * @property integer $robots
 * @property string $title
 * @property string $h1
 * @property string $meta_description
 * @property string $breadcrumbs_label
 * @property string $content
 * @property string $announce
 * @property integer $sort_order
 * @property string $date_added
 * @property string $date_modified
 * @property string $show_type
 * @property string $name
 * @property Page[] $children children of current page
 * @property Page $parent parent of current page
 * @property string|false $subdomain subdomain's name or false if it's not set
 * @property Image $images
 */
class Page extends ActiveRecord implements \JsonSerializable
{
    public $letter;
    public $import_excel;
    public $uploadImportDir = '/upload/import/';
    public $thumbnailDir    = '/thumbnail/page/';
    public $attributesKey = [ 0 => 'color', 1 => 'size', 2 => 'weight' ];

    private static $identity_map = [];

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%page}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['slug', 'name', 'category_id', 'content', 'announce', 'title' ], 'required'],
            ['import_excel', 'file', 'extensions' => ['xlsx'],'maxSize' => 1024 * 1024 * 10 ],
            [['robots', 'parent_id', 'sort_order','category_id'], 'integer'],
            [['slug_absolute', 'published', 'searchable', 'is_new'], 'boolean'],
            [
                [
                    'content',
                    'keywords',
                    'title',
                    'h1',
                    'meta_description',
                    'breadcrumbs_label',
                    'announce',
                    'slug_compiled',
                    'name'
                ],
                'string'
            ],
            [['date_added', 'date_modified','content','image', 'svg','tag_id','user_id', 'catalog_category_id'], 'safe'],
            [['slug'], 'string', 'max' => 80],
            [['slug_compiled'], 'string', 'max' => 180],
            [['show_type', 'subdomain'], 'string'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'id'                => Yii::t('app', 'ID'),
            'slug'              => Yii::t('app', 'Slug'),
            'slug_compiled'     => Yii::t('app', 'Slug Compiled'),
            'slug_absolute'     => Yii::t('app', 'Slug Absolute'),
            'content'           => Yii::t('app', 'Content'),
            'published'         => Yii::t('app', 'Published'),
            'searchable'        => Yii::t('app', 'Searchable'),
            'show_type'         => Yii::t('app', 'Show Type'),
            'robots'            => Yii::t('app', 'Robots'),
            'title'             => Yii::t('app', 'Title'),
            'h1'                => Yii::t('app', 'H1'),
            'meta_description'  => Yii::t('app', 'Meta Description'),
            'breadcrumbs_label' => Yii::t('app', 'Breadcrumbs Label'),
            'announce'          => Yii::t('app', 'Announce'),
            'sort_order'        => Yii::t('app', 'Sort Order'),
            'date_added'        => Yii::t('app', 'Date Added'),
            'date_modified'     => Yii::t('app', 'Date Modified'),
            'subdomain'         => Yii::t('app', 'Subdomain'),
            'name'              => Yii::t('app', 'Name'),
            'category_id'       => Yii::t('app', 'Category '),
            'tag_id'            => Yii::t('app', 'Tag'),
            'keywords'          =>  Yii::t('app', 'Keywords'),
            'user_id'           => Yii::t('app', 'User'),
            'catalog_category_id' => Yii::t('app', 'Catalog category'),
            'is_new'             => Yii::t('app', 'Новый'),
        ];
    }

    public function behaviors()
    {
        return [
            [
                'class' => MultilingualBehavior::className(),
                'languages' =>Language::getAllLanguages('local'),
                'languageField' => 'language',
              //'localizedPrefix' => '',
              //'requireTranslations' => false',
                'dynamicLangClass' => false,
                'langClassName' => PageTranslate ::className(), // or namespace/for/a/class/PostLang
                'defaultLanguage' => Language::getDefaultLang()->url,
                'langForeignKey' => 'page_id',
                'attributes' => [
                    'name',
                    'title',
                    'h1',
                    'meta_description',
                    'keywords',
                    'breadcrumbs_label',
                    'announce',
                    'content',
                ]
            ],
            [
                'class' => HasProperties::className(),
            ],
            [
                'class' => ActiveRecordHelper::className(),
            ],
            [
                'class' => Tree::className(),
                'activeAttribute' => 'published',
                'sortOrder' => [
                    'sort_order' => SORT_ASC,
                    'id' => SORT_ASC
                ],
            ],
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'date_added',
                'updatedAtAttribute' => 'date_modified',
                'value' => new Expression('NOW()'),
                'attributes' => [
                    ActiveRecord::EVENT_BEFORE_INSERT => ['date_added'],
                    ActiveRecord::EVENT_BEFORE_UPDATE => ['date_modified'],
                ],
            ],
        ];
    }

    /**
     * Search tasks
     * @param $params
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        /** @var $query \yii\db\ActiveQuery */
        $query = self::find();
        if (null != $this->parent_id) {
            $query->andWhere(['parent_id' => $this->parent_id]);
        }
        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            //'pagination' => [
            //    'pageSize' => 10,
            //],
        ]);
        if (!($this->load($params))) {
            return $dataProvider;
        }
        $query->andFilterWhere(['id' => $this->id]);
        $query->andFilterWhere(['like', 'slug', $this->slug]);
        $query->andFilterWhere(['like', 'slug_compiled', $this->slug_compiled]);
        $query->andFilterWhere(['like', 'slug_absolute', $this->slug_absolute]);
        $query->andFilterWhere(['published' => $this->published]);
        $query->andFilterWhere(['category_id' => $this->category_id]);
        
       $query->join('LEFT JOIN',
                       'pageTranslate pt',
                       'page.id = pt.page_id');
                       
        $query->andFilterWhere(['like', 'pt.name', $this->name]);
        $query->andFilterWhere(['like', 'pt.title', $this->title]);
        $query->andFilterWhere(['like', 'pt.h1', $this->h1]);
        $query->andFilterWhere(['like', 'pt.meta_description', $this->meta_description]);
        $query->andFilterWhere(['like', 'pt.breadcrumbs_label', $this->breadcrumbs_label]);
        
        return $dataProvider;
    }

    /**
     * @param int $id
     * @param int $is_published
     * @return mixed
     */
    public static function findById($id, $is_published = 1)
    {
        if (!isset(static::$identity_map[$id])) {

            $cacheKey = "Page:$id:$is_published";
            static::$identity_map[$id] = Yii::$app->cache->get($cacheKey);
            if (!is_object(static::$identity_map[$id])) {
                static::$identity_map[$id] = Page::findOne(['id' => $id, 'published' => $is_published]);

                if (is_object(static::$identity_map[$id])) {
                    Yii::$app->cache->set(
                        $cacheKey,
                        static::$identity_map[$id],
                        86400,
                        new TagDependency([
                            'tags' => [
                                ActiveRecordHelper::getCommonTag(static::className())
                            ]
                        ])
                    );
                }
            }
        }
        return static::$identity_map[$id];
    }

    /**
     * @inheritdoc
     */
    public function beforeSave($insert)
    {

        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }
        $this->slug_compiled = $this->compileSlug();
        TagDependency::invalidate(
            Yii::$app->cache,
            [
                ActiveRecordHelper::getCommonTag($this->className()),
                'Page:' . $this->slug_compiled
            ]
        );
        TagDependency::invalidate(
            Yii::$app->cache,
            [
                ActiveRecordHelper::getCommonTag($this->className()),
                'Page:' . $this->id . ':0'
            ]
        );
        TagDependency::invalidate(
            Yii::$app->cache,
            [
                ActiveRecordHelper::getCommonTag($this->className()),
                'Page:' . $this->id . ':1'
            ]
        );
        if (empty($this->breadcrumbs_label)) {
            $this->breadcrumbs_label = $this->title;
        }
        if (empty($this->h1)) {
            $this->h1 = $this->title;
        }

        if($this->position != 0){
            Page::updateAll(['position'=>0],['position'=>$this->position]);
        }
        
        if(Page::find()->where(['slug'=>$this->slug])->one()->id != $this->id){
            $this->slug = $this->slug.'_'.time();
            $this->slug_compiled = $this->slug;
        }

       $this->slug_compiled = $this->slug;

       if($this->catalog_category_id == '')
          $this->catalog_category_id = 0;

        return parent::beforeSave($insert);
    }
    /**
     * Attributes key
     *
     * @param string $key_index
     */
    public function getAttributesKey($key){
        return $this->attributesKey[$key];
    }

    /**
     * Compiles url for subdomain's links like http://subdomain.example.com
     *
     * Respects schema, relies on Yii::$app->getModule("core")->serverName as main domain name
     *
     * @param string $sub_domain
     * @param string $slug
     * @return string compiled url
     */
    private function compileUrl($sub_domain, $slug = "")
    {
        $schema = Yii::$app->request->isSecureConnection ? "https://" : "http://";
        $main_domain = Yii::$app->getModule("core")->serverName;

        return "{$schema}{$sub_domain}.{$main_domain}/{$slug}";
    }

    /**
     * Compiles slug based on parent compiled slug, slug absoluteness and subdomain property
     * @return string
     */
    public function compileSlug()
    {
        // accessing parent's model via Tree behaviour
        $parent_model = $this->parent;

        if (intval($this->slug_absolute) === 1) {
            $slug = $this->slug === ":mainpage:" ? "" : $this->slug;
            $subdomain = null;
            if (empty($this->subdomain) === false) {
                $subdomain = $this->subdomain;
            } elseif ($parent_model !== null) {
                if (empty($parent_model->subdomain) === false) {
                    // subdomain in parent is set - here is not
                    $subdomain = $parent_model->subdomain;
                }
            }

            if ($subdomain === null) {
                // subdomain is empty
                // no root
                return $this->slug;
            } else {
                return $this->compileUrl($subdomain, $slug);
            }
        } else {
            // not-absolute slug
            if ($parent_model !== null) {
                // should prepend parent's slug
                // can't be another domain then parent
                if ($parent_model->slug === ':mainpage:') {
                    return $this->slug;
                } else {
                    return $parent_model->slug_compiled . '/' . $this->slug;
                }
            } else {
                return ':mainpage:'; // it's main page
            }
        }
    }

    /**
     * @param string $path PATH из запроса ( $request->getPathInfo() )
     * @return mixed|null
     */
    public static function getByUrlPath($path = null)
    {
        if ((null === $path) || !is_string($path)) {
            return null;
        }
        $cacheKey = "Page:$path";
        $page = Yii::$app->cache->get($cacheKey);
        if ($page === false) {
            $page = static::find()->where(['slug_compiled' => $path, 'published' => 1])->asArray()->one();
            $duration = 86400;
            if (!is_array($page)) {
                $duration = 3600;
            }
            Yii::$app->cache->set(
                $cacheKey,
                $page,
                $duration,
                new TagDependency([
                    'tags' => [
                        ActiveRecordHelper::getCommonTag(static::className())
                    ]
                ])
            );
        }
        return $page;
    }

    /**
     * Preparation to delete page.
     * Deleting all inserted pages.
     * @return bool
     */
    public function beforeDelete() {

        if (!parent::beforeDelete()) {
            return false;
        }

        $images = $this->images;

        foreach($images as $image)
            $image->delete();

        foreach ($this->children as $child) {
            $child->delete();
        }
        return true;

    }

    public function getChildren() {
        return $this->hasMany(Page::className(), ['parent_id' => 'id'])->orderBy(['sort_order'=>SORT_ASC]);
    }

    /**
     * @return string
     */
    public function __toString()
    {
        return ($this->className() . ':' . $this->id);
    }

    /**
     * @return string
     */
    public function jsonSerialize() {
        return ($this->className() . ':' . $this->id);
    }
    
    public static function find() {
        $query = new MultilingualQuery(get_called_class());
        $query->localized();
        return $query;
    }
    
    public function getCategory() {
        return $this->hasOne(PageCategory::className(), ['id' =>'category_id'])->one();
    }

    public function getUser() {
        return $this->hasOne(User::className(), ['id' =>'user_id']);
    }

    public function  getThumbnail($width,$height) {

        $image = $width."-".$height."_".strtolower(substr(strrchr($this->image,"/"),1));
        
        $file = Yii::getAlias('@webroot'.$this->thumbnailDir).$image;
        
        if(file_exists($file)) {
            return '/thumbnail/page/'.$image;
        }else{

            if(!file_exists(Yii::getAlias('@webroot'.$this->thumbnailDir)))
                mkdir(Yii::getAlias('@webroot'.$this->thumbnailDir),0777);

            if(trim($this->image != "") AND file_exists(Yii::$app->basePath.'/web/files/'.$this->image)){
                 $thumb =  Image::thumbnail('files/'.$this->image, $width, $height,ManipulatorInterface::THUMBNAIL_OUTBOUND)
                  ->save(Yii::getAlias('@webroot/thumbnail/page/'.$width."-".$height."_".strtolower(substr(strrchr($this->image,"/"),1))), ['quality' => 100]);
                 return '/thumbnail/page/'.$image;
            }else{
                if(!file_exists(Yii::getAlias('@webroot').$this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg')){
                    $thumb =  Image::thumbnail('images/not_foto.jpg', $width, $height,ManipulatorInterface::THUMBNAIL_OUTBOUND)
                    ->save(Yii::getAlias('@webroot/thumbnail/page/'.$width."-".$height."_not_foto.jpg"), ['quality' => 100]);
                }

                return $this->thumbnailDir.$width.'-'.$height.'_not_foto.jpg';
            }
        }
    }

    public function getNextPreviousItem($array, $key)
    {
        $keys = array_keys($array);
        
        if ((false !== ($p = array_search($key, $keys))) && ($p <= count($keys) - 1) ){
            if($keys[$p-1])
            $result['previous'] =  array('key' => $keys[--$p], 'value' => $array[$keys[$p]]); 
        }
     
        if ((false !== ($p = array_search($key, $keys))) && ($p <= count($keys) - 1) ){   
            if($keys[$p+1])
                $result['next'] =  array('key' => $keys[++$p], 'value' => $array[$keys[$p]]);
               
        } 
        return $result;
    }

    public static function getListData() {

        $cacheKey = "PageListData";

        $pageListData = Yii::$app->cache->get($cacheKey);

        if ($pageListData === false) {

            $pageListData = ArrayHelper::map(Page::find()->all(),'id','name');
            Yii::$app->cache->set(
                $cacheKey,
                $pageListData,
                86400,
                new TagDependency([
                    'tags' => [
                        ActiveRecordHelper::getCommonTag(self::className())
                    ]
                ])
            );
        }
        return $pageListData;
    }

    public function getImages() {
        return $this->hasMany(PageImages::className(), ['object_id' => 'id'])->orderBy(['sort'=>SORT_ASC]);
    }

    public function getImagesNoMain() {
        return $this->hasMany(PageImages::className(), ['object_id' => 'id'])->andWhere(['main'=>0])->orderBy(['sort'=>SORT_ASC]);
    }

    public function getMainImage() {
        return $this->hasOne(PageImages::className(), ['object_id' => 'id'])->where('main = 1');
    }

    public function getModelImage() {
            return new PageImages();
    }

    public function UploadImportFile($model) {
        $file =  UploadedFile::getInstance($model,'import_excel');

        if ($file !== null)
        {
            $prefx = rand(100,999).'_'.time();

            $fileName  = $prefx.'.'.$file->extension;

            if(!file_exists(Yii::getAlias('@webroot'.$this->uploadImportDir)))
                mkdir(Yii::getAlias('@webroot'.$this->uploadImportDir),0777);

            $uploadDir = Yii::getAlias('@webroot'.$this->uploadImportDir);

            $fn = $uploadDir . $fileName;

            $file->saveAs($fn);

            return $fn;
        }else
           return false;
           // throw new NotFoundHttpException('Error upload file');
    }

    public function getCategoryType() {
        return $this->hasOne(CategoryType::className(), ['page_id' => 'id']);
    }

}