<?php

namespace app\modules\page\models;



use Yii;
use yii\data\ActiveDataProvider;
use yii\web\NotFoundHttpException;
use yii\web\UploadedFile;
use yii\imagine\Image;
use Imagine\Image\ManipulatorInterface;

class PageImages extends \yii\db\ActiveRecord
{

    public $uploadDir = '/upload/page/';
    public $thumbnailDir = '/thumbnail/page';

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;

    public static function tableName()
    {
        return '{{%pageImages}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['file_name','object_id'], 'required'],
            [['object_id', 'sort'], 'integer'],
            [['file_name'], 'string', 'max' => 255],
            [['file_name', 'main', 'date_created','id'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'                => 'ID',
            'object_id'         => Yii::t('app', 'Object'),
            'file_name'         => Yii::t('app', 'File'),
            'main'              => Yii::t('app', 'Main'),
            'date_created'      => Yii::t('app', 'Created'),
            'sort'              => Yii::t('app', 'Sort'),
        ];
    }

    public function UploadFile($model)
    {
        $file =  UploadedFile::getInstanceByName('images');

        if ($file !== null)
        {
            $prefx = rand(100,999).'_'.time();

            $fileName  = $model->id.'_'.$prefx.'.'.$file->extension;

            if(!file_exists(Yii::getAlias('@webroot'.$this->uploadDir)))
                mkdir(Yii::getAlias('@webroot'.$this->uploadDir),0777);

            $uploadDir = Yii::getAlias('@webroot'.$this->uploadDir);

            $fn = $uploadDir . $fileName;

            $file->saveAs($fn);

            return str_replace(Yii::getAlias('@webroot'), '', $uploadDir).$fileName;
        }else
            throw new NotFoundHttpException('Error upload file');
    }

    public function UploadOneFile($model)
    {
        $files =  UploadedFile::getInstancesByName('Page');

        if ($files) {

            foreach($files as $file)

            $prefx = rand(100,999).'_'.time();

            $fileName  = $model->id.'_'.$prefx.'.'.$file->extension;

            if(!file_exists(Yii::getAlias('@webroot'.$this->uploadDir)))
                mkdir(Yii::getAlias('@webroot'.$this->uploadDir),0777);

            $uploadDir = Yii::getAlias('@webroot'.$this->uploadDir);

            $fn = $uploadDir . $fileName;

            $file->saveAs($fn);

            return str_replace(Yii::getAlias('@webroot'), '', $uploadDir).$fileName;
        }else
            return false;
    }

    public function  getThumbnailNotImage($width,$height) {
        if(!file_exists(Yii::getAlias('@webroot').$this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg')){
            $thumb =  Image::thumbnail('files/images/not_foto.jpg', $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_not_foto.jpg"), ['quality' => 100]);
            return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';
        }else
            return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';
    }

    public function  getThumbnail($width,$height) {
        $image = $width."-".$height."_".strtolower(substr(strrchr($this->file_name,"/"),1));

        $file = Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$image);

        if(file_exists($file)) {
            return $this->thumbnailDir.'/'.$image;
        }else {

            if(!file_exists(Yii::getAlias('@webroot'.$this->thumbnailDir)))
                mkdir(Yii::getAlias('@webroot'.$this->thumbnailDir),0777);

            if(trim($this->file_name != "") AND file_exists(Yii::getAlias('@webroot').$this->file_name)){

                $thumb =  Image::thumbnail('@webroot'.$this->file_name, $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                    ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_".strtolower(substr(strrchr($this->file_name,"/"),1))), ['quality' => 100]);
                return $this->thumbnailDir.'/'.$image;

            }else{

                if(!file_exists(Yii::getAlias('@webroot').$this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg')){
                    $thumb =  Image::thumbnail('images/not_foto.jpg', $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                        ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_not_foto.jpg"), ['quality' => 100]);
                    return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';
                }else
                    return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';

            }
        }
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_ACTIVE   => Yii::t('app','Active'),
            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
        ];

        return $label_status[$status];
    }


    public function beforeSave($insert)
    {
        if($this->isNewRecord){
            $this->date_created = date('Y-m-d',time());
            if(!PageImages::find()->where('object_id = '.$this->object_id.' AND main = 1')->one())
                $this->main = 1;
        }



        return parent::beforeSave($insert);
    }

    public function beforeDelete()
    {
        if (parent::beforeDelete()) {

            if($this->main == 1 AND ($image = PageImages::find()->where('object_id = '.$this->object_id)->one())) {
                $image->main = 1;
                $image->update();
            }

            $fileDir = Yii::getAlias('@webroot'.$this->file_name);

            if(file_exists($fileDir) )
                unlink($fileDir);

            return true;
        } else {
            return false;
        }
    }
}
