<?php

namespace app\modules\regions\models;

use Yii;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use yii\db\ActiveRecord;
use app\modules\core\models\Language;
use omgdef\multilingual\MultilingualBehavior;
use omgdef\multilingual\MultilingualQuery;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\helpers\ArrayHelper;

class Area extends ActiveRecord
{

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;


    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%area}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name'], 'required'],
            [['status','city_id'], 'integer'],
            [['name'], 'string'],
            [['name',], 'string', 'max' => 250],
            [['name','id'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'                 => 'ID',
            'name'               => Yii::t('app', 'Name'),
            'status'             => Yii::t('app', 'Status'),
            'city_id'            => Yii::t('app', 'City'),
        ];
    }

    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->join('LEFT JOIN',
            'areaTranslate t',
            self::tableName().'.id = t.object_id');
        $query->andFilterWhere(['like', 't.name', $this->name]);

        return $dataProvider;
    }

    public function behaviors()
    {
        $multilingualBehavior = [
            'ml' => [
                'class' => MultilingualBehavior::className(),
                'languages' =>Language::getAllLanguages('local'),
                'dynamicLangClass' => false,
                'langClassName' => AreaTranslate::className(),
                'defaultLanguage' => Language::getDefaultLang()->url,
                'langForeignKey' => 'object_id',
                'attributes' => [
                    'name',
                ]
            ],
        ];
        return $multilingualBehavior;
    }

    public static function find() {
        $query = new MultilingualQuery(get_called_class());
        $query->localized();
        return $query;
    }

    public static function getListData() {
        return ArrayHelper::map(Area::find()->leftJoin('areaTranslate','"area".id = "areaTranslate".object_id')->orderBy(['"areaTranslate".name'=>SORT_ASC])->all(),'id','name');
    }

    public function beforeSave($insert)
    {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        TagDependency::invalidate(Yii::$app->cache, 'List-Data-City-Area');

        if($this->isNewRecord){

        }

        return parent::beforeSave($insert);
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_ACTIVE   => Yii::t('app','Active'),
            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
        ];

        return $label_status[$status];
    }

    public function beforeDelete()
    {
        if (parent::beforeDelete()) {

            return true;
        } else {
            return false;
        }
    }
}
