<?php

namespace app\modules\regions\models;

use Yii;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use yii\db\ActiveRecord;
use app\modules\core\models\Language;
use omgdef\multilingual\MultilingualBehavior;
use omgdef\multilingual\MultilingualQuery;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\helpers\ArrayHelper;

class City extends ActiveRecord
{

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;


    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%city}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name','country_id'], 'required'],
            [['status'], 'integer'],
            [['name'], 'string'],
            [['name',], 'string', 'max' => 250],
            [['name','id'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'                 => 'ID',
            'name'               => Yii::t('app', 'Name'),
            'status'             => Yii::t('app', 'Status'),
            'country_id'         => Yii::t('app', 'Country'),
        ];
    }

    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->join('LEFT JOIN',
            'cityTranslate t',
            self::tableName().'.id = t.object_id');
        $query->andFilterWhere(['like', 't.name', $this->name]);

        return $dataProvider;
    }

    public function behaviors()
    {
        $multilingualBehavior = [
            'ml' => [
                'class' => MultilingualBehavior::className(),
                'languages' =>Language::getAllLanguages('local'),
                'dynamicLangClass' => false,
                'langClassName' => CityTranslate::className(),
                'defaultLanguage' => Language::getDefaultLang()->url,
                'langForeignKey' => 'object_id',
                'attributes' => [
                    'name',
               ]
            ],
        ];
        return $multilingualBehavior;
    }

    public static function find()
    {
        $query = new MultilingualQuery(get_called_class());
        $query->localized();
        return $query;
    }

    public function beforeSave($insert)
    {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        TagDependency::invalidate(Yii::$app->cache, 'List-Data-City-Area');

        if($this->isNewRecord){

        }

        return parent::beforeSave($insert);
    }

    public static function getStatusLabel($status) {
        $label_status = [
                            self::STATUS_ACTIVE   => Yii::t('app','Active'),
                            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
                        ];
        return $label_status[$status];
    }

    public static function getListData() {
        return ArrayHelper::map(City::find()->leftJoin('cityTranslate','city.id = cityTranslate.object_id')->orderBy(['cityTranslate.name'=>SORT_ASC])->all(),'id','name');
    }

    public function getAreas() {
        return $this->hasMany(Area::className(), ['object_id' => 'id'])->all();
    }

    public static function getListDataCityArea() {

        $cacheKey = "ListDataCityArea-Key".Yii::$app->language;
        $data = Yii::$app->cache->get($cacheKey);

        if ($data === false) {

            $citys = City::find()->where(['status'=>1])->leftJoin('cityTranslate','"city".id = "cityTranslate".object_id')->orderBy(['"cityTranslate".name'=>SORT_ASC])->all();
            $data  = [];

            foreach($citys as $city){
                $areaArray = [];
                foreach($city->getAreas() as $area){
                        $areaArray[$area->id] = $area->name;

                    $data[$city->id] = [
                        'name'=>$city->name,
                        'items'=>$areaArray
                    ];
               }

                Yii::$app->cache->set(
                    $cacheKey,
                    $data,
                    86400,
                    new TagDependency([
                        'tags' => 'List-Data-City-Area'
                    ])
                );
            }
        }
        return $data;
    }


    public static function getListDataForCountry($country_id) {
        if($country_id)
            return ArrayHelper::map(City::find()->where(['country_id'=>$country_id])->all(),'id','name');
        else
            return false;
    }

    public function beforeDelete()
    {
        if (parent::beforeDelete()) {

            return true;
        } else {
            return false;
        }
    }
}
