<?php

namespace app\modules\regions\models;

use Imagine\Image\ManipulatorInterface;
use Yii;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use yii\db\ActiveRecord;
use app\modules\core\models\Language;
use omgdef\multilingual\MultilingualBehavior;
use omgdef\multilingual\MultilingualQuery;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\helpers\ArrayHelper;
use yii\imagine\Image;
use yii\web\UploadedFile;

class Country extends ActiveRecord
{

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;

    const MATERIKI_1 = 1;
    const MATERIKI_2 = 2;
    const MATERIKI_3 = 3;
    const MATERIKI_4 = 4;
    const MATERIKI_5 = 5;
    const MATERIKI_6 = 6;

    public $uploadDir = '/upload/country/';
    public $thumbnailDir = '/thumbnail/country';

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%country}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name'], 'required'],
            [['status'], 'integer'],
            [['name'], 'string'],
            [['name',], 'string', 'max' => 250],
            [['name', 'id', 'flag', 'materiki'], 'safe'],

        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'                 => 'ID',
            'name'               => Yii::t('app', 'Name'),
            'status'             => Yii::t('app', 'Status'),
            'flag'               => 'Flag',
            'materiki'           => 'Materiki',
        ];
    }

    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->join('LEFT JOIN',
            'countryTranslate t',
            self::tableName().'.id = t.object_id');
        $query->andFilterWhere(['like', 't.name', $this->name]);

        return $dataProvider;
    }
    /*
       public function behaviors()
       {

           $multilingualBehavior = [
               'ml' => [
                   'class' => MultilingualBehavior::className(),
                   'languages' =>Language::getAllLanguages('local'),
                   'dynamicLangClass' => false,
                   'langClassName' => CountryTranslate::className(),
                   'defaultLanguage' => Language::getDefaultLang()->url,
                   'langForeignKey' => 'object_id',
                   'attributes' => [

                   ]
               ],
           ];
           return $multilingualBehavior;

       }
       */
    /*
        public static function find()
        {

            $query = new MultilingualQuery(get_called_class());
            $query->localized();
            return $query;

    }
    */
    public function beforeSave($insert)
    {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        if($this->isNewRecord){

        }

        return parent::beforeSave($insert);
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_ACTIVE   => Yii::t('app','Active'),
            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
        ];

        return $label_status[$status];
    }

    public static function getListData() {
        return ArrayHelper::map(Country::find()->all(),'id','name');
    }

    public function beforeDelete()
    {
        if (parent::beforeDelete()) {

            return true;
        } else {
            return false;
        }
    }

    public function uploadFile() {

        $file =  UploadedFile::getInstancesByName('Country');

        $file = $file[0];

        if ($file) {
            $prefx = rand(100,999).'_'.time();
            $fileName  = $this->id.'_'.$prefx.'.'.$file->extension;
            if(!file_exists(Yii::getAlias('@webroot'.$this->uploadDir)))
                mkdir(Yii::getAlias('@webroot'.$this->uploadDir),0777);

            $uploadDir = Yii::getAlias('@webroot'.$this->uploadDir);
            $fn = $uploadDir . $fileName;
            $file->saveAs($fn);
            return str_replace(Yii::getAlias('@webroot'), '', $uploadDir).$fileName;
        }else
            return false;
    }

    public function  getThumbnail($width,$height) {
        $flag = $width."-".$height."_".strtolower(substr(strrchr($this->flag,"/"),1));

        $file = Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$flag);

        if(file_exists($file)) {
            return $this->thumbnailDir.'/'.$flag;
        }else {

            if(!file_exists(Yii::getAlias('@webroot'.$this->thumbnailDir)))
                mkdir(Yii::getAlias('@webroot'.$this->thumbnailDir),0777);

            if(trim($this->flag != "") AND file_exists(Yii::getAlias('@webroot').$this->flag)){

                $thumb =  Image::thumbnail('@webroot'.$this->flag, $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                    ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_".strtolower(substr(strrchr($this->flag,"/"),1))), ['quality' => 100]);
                return $this->thumbnailDir.'/'.$flag;

            }else{

                if(!file_exists(Yii::getAlias('@webroot').$this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg')){
                    $thumb =  Image::thumbnail('images/not_foto.jpg', $width, $height,ManipulatorInterface::THUMBNAIL_INSET)
                        ->save(Yii::getAlias('@webroot'.$this->thumbnailDir.'/'.$width."-".$height."_not_foto.jpg"), ['quality' => 100]);
                    return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';
                }else
                    return $this->thumbnailDir.'/'.$width.'-'.$height.'_not_foto.jpg';

            }
        }
    }

    public function deleteImage() {
        $fileDir = Yii::getAlias('@webroot/'.$this->oldAttributes['flag']);
        if(file_exists($fileDir) AND $this->oldAttributes['flag'] != '') {
            unlink($fileDir);
            return true;
        }else
            return false;
    }

    public static function getMaterikiList(){
        return [
            Language::MATERIKI_1 => Yii::t('app','Asia'),
            Language::MATERIKI_2 => Yii::t('app','Europe'),
            Language::MATERIKI_3 => Yii::t('app','Africa'),
            Language::MATERIKI_4 => Yii::t('app','Australia'),
            Language::MATERIKI_5 => Yii::t('app','North America'),
            Language::MATERIKI_6 => Yii::t('app','South America'),
        ];
    }

    public function getLanguage(){

     return $languages = Language::find()
            ->join('LEFT JOIN',
                 'countryLanguage cl',
                 'cl.language_id = language.id')
            ->where(['country_id' => $this->id]);

    }

}
