<?php

namespace app\modules\regions\models;

use Yii;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use yii\db\ActiveRecord;
use app\modules\core\models\Language;
use omgdef\multilingual\MultilingualBehavior;
use omgdef\multilingual\MultilingualQuery;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\helpers\ArrayHelper;
use yii\web\UploadedFile;
use app\modules\regions\models\Country;

class CountryLanguage extends ActiveRecord
{

    const STATUS_INACTIVE = 0;
    const STATUS_ACTIVE   = 1;


    /**
     * @inheritdoc
     */
    public static function tableName()  {
        return '{{%countryLanguage}}';
    }

    /**
     * @inheritdoc
     */
    public function rules() {
        return [
            [['country_id', 'language_id'], 'required'],
            [['id'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels() {
        return [
            'id'                => 'ID',
            'country_id'        => 'Country',
            'language_id'       => 'Language',
        ];
    }

    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.country_id' => $this->country_id]);
        $query->andFilterWhere([self::tableName().'.language_id' => $this->language_id]);

        return $dataProvider;
    }

    public function beforeSave($insert)
    {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        if($this->isNewRecord){

        }

        return parent::beforeSave($insert);
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_ACTIVE   => Yii::t('app','Active'),
            self::STATUS_INACTIVE => Yii::t('app','Inactive'),
        ];

        return $label_status[$status];
    }

    public function beforeDelete()
    {
        if (parent::beforeDelete()) {

            return true;
        } else {
            return false;
        }
    }

    public function getCountry() {
        return $this->hasOne(Country::className(), ['id' =>'country_id']);
    }

    public function getLanguage() {
        return $this->hasOne(Language::className(), ['id' =>'language_id']);
    }
}
