<?php

namespace app\modules\review\controllers;

use Yii;
use app\modules\review\models\Rating;
use yii\db\ActiveRecord;
use yii\filters\AccessControl;
use yii\helpers\Url;
use yii\bootstrap\Html;
use yii\web\BadRequestHttpException;
use yii\web\NotFoundHttpException;
use yii\web\Response;



class BackendRatingController extends \app\backend\components\BackendController
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['review manage'],
                    ],
                ],
            ],
        ];
    }

    public function actionIndex() {

        $searchModel = new Rating();

        $params = Yii::$app->request->get();
        $dataProvider = $searchModel->search($params);

        return $this->render(
            'index',
            [
                'dataProvider' => $dataProvider,
                'searchModel' => $searchModel,
            ]
        );
    }

    public function actionEdit($id = null) {

        $request = Yii::$app->request;

        $model = new Rating;
        if ($id !== null) {
            $model = Rating::find()->where(['id'=>$id])->one();
            if ($model === null) {
                throw new NotFoundHttpException;
            }
        }

        if ($model->load($request->post())) {

            if ($model->save()) {

                Yii::$app->session->setFlash('info', Yii::t('app', 'Object saved'));
                $returnUrl = $request->get('returnUrl');
                switch ($request->post('action', 'save')) {
                    case 'next':
                        return $this->redirect(
                            [
                                '/review/backend-review/edit',
                                'returnUrl' => $returnUrl,
                            ]
                        );
                    case 'back':
                        return $this->redirect($returnUrl);
                    default:
                        return $this->redirect(
                            Url::toRoute(
                                [
                                    '/review/backend-review/edit',
                                    'id' => $model->id,
                                    'returnUrl' => $returnUrl,
                                ]
                            )
                        );
                }
            }else
                Yii::$app->session->setFlash('error', Yii::t('app', 'Cannot update data'));
        }

        return $this->render('edit', [
            'model' => $model,
        ]);
    }



}
