<?php

namespace app\modules\review\controllers;

use Yii;
use app\modules\review\models\Review;
use yii\db\ActiveRecord;
use yii\filters\AccessControl;
use yii\helpers\Url;
use yii\bootstrap\Html;
use yii\web\BadRequestHttpException;
use yii\web\NotFoundHttpException;
use yii\web\Response;


class BackendReviewController extends \app\backend\components\BackendController
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['review manage'],
                    ],
                ],
            ],
        ];
    }

    public function actionIndex() {

        $searchModel = new Review();

        $params = Yii::$app->request->get();
        $dataProvider = $searchModel->search($params);

        return $this->render(
            'index',
            [
                'dataProvider' => $dataProvider,
                'searchModel' => $searchModel,
            ]
        );
    }

    public function actionEdit($id = null) {

        $request = Yii::$app->request;

        $model = new Review;
        if ($id !== null) {
            $model = Review::find()->where(['id'=>$id])->one();
            if ($model === null) {
                throw new NotFoundHttpException;
            }
        }

        if ($model->load($request->post())) {

            if ($model->save()) {

                Yii::$app->session->setFlash('info', Yii::t('app', 'Object saved'));
                $returnUrl = $request->get('returnUrl');
                switch ($request->post('action', 'save')) {
                    case 'next':
                        return $this->redirect(
                            [
                                '/review/backend-review/edit',
                                'returnUrl' => $returnUrl,
                            ]
                        );
                    case 'back':
                        return $this->redirect($returnUrl);
                    default:
                        return $this->redirect(
                            Url::toRoute(
                                [
                                    '/review/backend-review/edit',
                                    'id' => $model->id,
                                    'returnUrl' => $returnUrl,
                                ]
                            )
                        );
                }
            }else
                Yii::$app->session->setFlash('error', Yii::t('app', 'Cannot update data'));
        }

        return $this->render('edit', [
            'model' => $model,
        ]);
    }

    public function actionUpdateReview()
    {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $post = Yii::$app->request->post();

        if (!isset($post['editableIndex'], $post['editableKey'])) {
            throw new BadRequestHttpException;
        }

        $id = $post['editableKey'];
        /** @var User Package */
        $model = Review::findOne($id);
        if ($model === null) {
            throw new BadRequestHttpException;
        }

        $index = $post['editableIndex'];
        if (!is_array($post['Review'][$index])) {
            throw new BadRequestHttpException;
        }

        if (count($post['Review'][$index])===0) {
            throw new BadRequestHttpException;
        }

        $modifiedAttribute = array_keys($post['Review'][$index])[0];

        $model->setAttributes($post['Review'][$index]);

        if (!$model->save()) {
            return [
                'message' => Yii::t('app', 'Cannot save object'),
            ];
        }

        if ($modifiedAttribute === 'status') {

            if ($model->status == 0) {
                $label_class = 'label-info';
                $value = Review::getStatusLabel((Review::STATUS_NEW));
            }elseif ($model->status == 1) {
                $label_class = 'label-success';
                $value = Review::getStatusLabel(Review::STATUS_APPROVED);
            }elseif ($model->status == 2) {
                $label_class = 'label-default';
                $value = Review::getStatusLabel(Review::STATUS_NOT_APPROVED);
            }

            $model->status = Html::tag(
                'span',
                Yii::t('app', $value),
                ['class' => "label $label_class"]
            );

        }

        return [
            'output' => $model->getAttribute($modifiedAttribute),
        ];
    }

    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }


    protected function findModel($id)
    {
        if (($model = Review::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
