<?php

namespace app\modules\review\models;

use app\modules\user\models\User;
use Yii;

use yii\db\ActiveRecord;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use devgroup\TagDependencyHelper\ActiveRecordHelper;

class Rating extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%rating}}';
    }

    /**
     * @return array
     */
    public function behaviors()
    {
        return [
            [
                'class' => ActiveRecordHelper::className(),
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['object_id', 'object_class_name', 'user_id'], 'required'],
            [['object_id', 'user_id' ,'value'], 'integer'],
            [['ip_address','date_created'], 'safe'],
            [['ip_address','object_class_name'], 'string'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'object_id' => Yii::t('app', 'Object ID'),
            'object_class_name' => Yii::t('app', 'Object Class Name'),
            'ip_address' => Yii::t('app', 'IP Address'),
            'value' => Yii::t('app', 'Value'),
            'user_id' => Yii::t('app', 'User'),
            'date_created' => Yii::t('app', 'Data created'),
        ];
    }

    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);

        return $dataProvider;
    }

    public function beforeSave($insert) {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        TagDependency::invalidate(Yii::$app->cache, $this->object_class_name.'_'.$this->object_id);

        if($this->isNewRecord){
            $this->date_created = date("Y-m-d H:i",time());
        }

        return parent::beforeSave($insert);
    }

    public function getUser() {
        return $this->hasOne(User::className(), ['id' => 'user_id']);
    }
}
