<?php

namespace app\modules\review\models;

use app\modules\user\models\User;
use Yii;
use devgroup\TagDependencyHelper\ActiveRecordHelper;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;


class Review extends \yii\db\ActiveRecord
{
    const STATUS_NEW = '0';
    const STATUS_APPROVED = '1';
    const STATUS_NOT_APPROVED = '2';

    public $rating;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%review}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        $rules = [
            [['review_text','user_id','object_id','object_class_name','ip_address','rating'],'required'],
            [['user_id','object_id','status','rating_id','rating'], 'integer'],
            [['review_text','ip_address'],'string'],
            ['author_email', 'email'],
            [['status'], 'default', 'value' => 0],
            [['update','date_created'], 'safe'],
        ];
        return $rules;
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            [
                'class' => ActiveRecordHelper::className(),
            ]
        ];
    }

    public static function getStatuses() {
        return [
            self::STATUS_NEW          => Yii::t('app', 'New'),
            self::STATUS_APPROVED     => Yii::t('app', 'Approved'),
            self::STATUS_NOT_APPROVED => Yii::t('app', 'Not approved'),
        ];
    }

    public static function getStatusLabel($status) {

        $label_status = [
            self::STATUS_NEW          => Yii::t('app', 'New'),
            self::STATUS_APPROVED     => Yii::t('app', 'Approved'),
            self::STATUS_NOT_APPROVED => Yii::t('app', 'Not approved'),
        ];

        return $label_status[$status];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'                => Yii::t('app', 'ID'),
            'object_id'         => Yii::t('app', 'Object ID'),
            'object_class_name' => Yii::t('app', 'Object Class Name'),
            'author_email'      => Yii::t('app', 'Author email'),
            'review_text'       => Yii::t('app', 'Review text'),
            'status'            => Yii::t('app', 'Status'),
            'rating_id'         => Yii::t('app', 'Rating'),
            'date_created'      => Yii::t('app', 'Date created '),
            'update'            => Yii::t('app', 'update'),
            'ip_address'        => Yii::t('app', 'IP Address'),
            'rating'            => Yii::t('app', 'Rating'),
        ];
    }

    public function search($params)
    {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 15,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);

        return $dataProvider;
    }

    public function beforeSave($insert) {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        TagDependency::invalidate(Yii::$app->cache, $this->object_class_name.'_'.$this->object_id);

        if($this->isNewRecord){
            $this->date_created = date("Y-m-d H:i",time());
            $this->status       = 0;
        }

        return parent::beforeSave($insert);
    }

    public function beforeDelete() {
        if (false === parent::beforeDelete()) {
            return false;
        }

        return true;
    }

    public function getUser() {
        return $this->hasOne(User::className(), ['id' => 'user_id']);
    }

    public function getRating() {
        return $this->hasOne(Rating::className(), ['id' => 'rating_id']);
    }
}
