<?php

/**
 * @var yii\web\View $this
 * @var yii\data\ActiveDataProvider $dataProvider
 * @var app\backgroundtasks\models\Task $searchModel
 */

use kartik\dynagrid\DynaGrid;
use kartik\helpers\Html;
use yii\helpers\Url;
use kartik\grid\GridView;
use app\modules\review\models\Review;
use app\backend\components\ActionColumn;
use kartik\icons\Icon;
use \devgroup\JsTreeWidget\ContextMenuHelper;
use \app\backend\components\Helper;
use \kartik\popover\PopoverX;
use kartik\grid\EditableColumn;
use kartik\editable\Editable;
use kartik\grid\SerialColumn;
use app\modules\user\models\User;
use yii\web\JsExpression;


$this->title = Yii::t('app', 'Reviews');
$this->params['breadcrumbs'][] = $this->title;
?>

<div class="row">
    <div class="col-sm-12">
        <?

        $columns = [
            ['class'=>'kartik\grid\SerialColumn'],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'id',
                'options' => [
                    'width' => '40px',
                ],
            ],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'user_id',
                'options' => [
                    'width' => '200px',
                ],
                'value'=>function($data) {
                    return $data->getUser()->one()->first_name.' '.$data->getUser()->one()->last_name;
                },
                'filterType'=>GridView::FILTER_SELECT2,
                'filterWidgetOptions'=>[

                    'pluginOptions' => [
                        'allowClear' => true,
                        'minimumInputLength' => 3,
                        'language' => [
                            'errorLoading' => new JsExpression("function () { return 'Waiting for results...'; }"),
                        ],
                        'ajax' => [
                            'url' => Url::to(['/user/backend-user/ajax-list-data']),
                            'dataType' => 'json',
                            'data' => new JsExpression('function(params) { return {q:params.term}; }')
                        ],
                        'escapeMarkup' => new JsExpression('function (markup) { return markup; }'),
                        'templateResult' => new JsExpression('
                                function(data) {
                                        return data.id+" "+data.first_name+" "+data.last_name;
                                    }
                                '),
                        'templateSelection' => new JsExpression('function (data) {
                                    return data.id;
                                }'),
                    ],
                ],
                'filterInputOptions' => ['placeholder' => 'Type a position'],
                'format'=>'raw',
            ],
            'object_id',
            'object_class_name',
            'value',
            'ip_address',
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'date_created',
                'options' => [
                    'width' => '100px',
                ],
                'filterType'=>GridView::FILTER_DATE,
                'filterWidgetOptions'=>[
                    'pluginOptions' => [
                        'allowClear' => true,
                        'format' => 'yyyy-m-dd',
                        'todayHighlight' => true,
                        'autoclose' => true,
                        'orientation' => 'auto',
                        //'container' => '#date_created-kvdate'
                    ],
                ],
                'filterInputOptions' => ['placeholder' => Yii::t('app','Date start')],
                'format'=>'raw',
            ],


            [
                'class'=>'kartik\grid\ActionColumn',
                'template' => '<div class="btn-group ">{view} {update} {delete}</div>  ',

                'dropdown'=>false,
                'urlCreator'=>function($action, $model, $key, $index) {

                    if($action == 'delete')
                        return Url::to(['/review/backend-review/delete','id'=>$model->id]);

                   // if($action == 'update')
                     //   return Url::to(['/review/backend-review/edit','id'=>$model->id]);

                    return $action; },
                'viewOptions'=>['hidden'=>true],
                'updateOptions'=>['hidden'=>true],

                /*
                'updateOptions'=>[
                    'title'=>Yii::t('app', 'Edit'),
                    'class' => 'btn btn-primary btn-xs',
                    'data-toggle'=>'tooltip'],
                */
                'deleteOptions'=>[
                    'icon' => 'trash-o',
                    'class' => 'btn btn-danger btn-xs',
                    'title' => Yii::t('app', 'Delete'),
                    'data-toggle'=>'tooltip',
                    'data-pjax'=>true,
                    'data-pjax-container'=>"dynagrid-1-pjax"
                ],

            ],
        ];


        echo GridView::widget([
            'dataProvider' => $dataProvider,
            'filterModel'  => $searchModel,
            'columns' => $columns,
            'containerOptions' => ['style'=>'overflow: visible'], // only set when $responsive = false
            'floatOverflowContainer'=> false,
            'pjax' => false,
            'bordered' => true,
            'persistResize'=>true,
            'striped' => true,
            'condensed' => false,
            'responsive' => true,
            'hover' => true,
            'floatHeader' => false,
            'floatHeaderOptions' => ['scrollingTop' => 10],
            'showPageSummary' => true,
            'panel' => [
                'type' => GridView::TYPE_DEFAULT,
               /*
                'after' => Html::a(
                    Icon::show('plus') . Yii::t('app', 'Add'),
                    ['/review/backend-review/edit', 'returnUrl' => \app\backend\components\Helper::getReturnUrl()],
                    ['class' => 'btn btn-success']
                ),
                */
            ],
        ]);


        ?>

    </div>
</div>