<?php

namespace app\modules\sms\models;

use Yii;
use yii\helpers\ArrayHelper;
use yii\caching\TagDependency;
use yii\data\ActiveDataProvider;
use app\components\MedBaseActiveRecord;
use devgroup\TagDependencyHelper\ActiveRecordHelper;

class SmsLog extends MedBaseActiveRecord {

    public static function tableName() {
        return '{{%smsLog}}';
    }

    public function rules() {
        return [
            [['sms_id','phone','error_msg','status'], 'required'],
            [['id','date_created'], 'safe'],
        ];
    }

    public function attributeLabels() {
        return [
            'id'           => 'ID',
            'status'       => Yii::t('app', 'Status'),
            'sms_id'       => Yii::t('app', 'Sms id'),
            'phone'        => Yii::t('app', 'Phone'),
            'date_created' => Yii::t('app', 'Date created'),
        ];
    }

    public function search($params) {
        $query = self::find();
        $dataProvider = new ActiveDataProvider(
            [
                'query' => $query,
                'pagination' => [
                    'pageSize' => 30,
                ],
            ]
        );

        if (!($this->load($params))) {
            return $dataProvider;
        }

        $query->andFilterWhere([self::tableName().'.id' => $this->id]);
        $query->andFilterWhere([self::tableName().'.status' => $this->status]);
        $query->andFilterWhere([self::tableName().'.sms_id' => $this->sms_id]);
        $query->andFilterWhere(['like', self::tableName().'.phone', $this->phone]);
        $query->andFilterWhere(['like', self::tableName().'.date_created', $this->date_created]);

        return $dataProvider;
    }

    public function beforeSave($insert) {
        if (!$insert) {
            // reset a cache tag to get a new parent model below
            TagDependency::invalidate(Yii::$app->cache, [ActiveRecordHelper::getCommonTag(self::className())]);
        }

        if($this->isNewRecord){
            $this->date_created = date("Y-m-d H:i",time());
        }

        return parent::beforeSave($insert);
    }

    public function getStatus($status = 0) {

        $_error_codes = Yii::$app->sms->_error_codes;
        return $_error_codes[$status];
    }
}
