<?php

namespace app\modules\user\controllers;

use app\backend\components\Helper;
use app\modules\askdoctor\models\DoctorReception;
use app\modules\medbase\models\MedHistory;
use app\modules\notification\models\Notification;
use app\modules\regions\models\City;
use app\modules\user\actions\AuthAction;
use app\modules\user\models\LoginForm;
use app\modules\user\models\UserFile;
use app\modules\user\models\PasswordResetRequestForm;
use app\modules\user\models\PhoneActive;
use app\modules\user\models\RegistrationForm;
use app\modules\user\models\ResetPasswordForm;
use app\modules\user\models\User;
use app\modules\user\models\UserService;
use app\modules\user\models\UserRating;
use app\modules\seo\behaviors\MetaBehavior;
use app\modules\core\models\Language;
use \Yii;
use yii\base\ErrorException;
use yii\base\InvalidParamException;
use yii\caching\TagDependency;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\web\BadRequestHttpException;
use app\components\Controller;
use yii\web\NotFoundHttpException;
use yii\web\Response;
use app\components\AuthClientHelper;
use yii\web\UploadedFile;
use yii\helpers\Html;
use yii\data\ActiveDataProvider;
use app\modules\askdoctor\models\QuestionsTheme;
use app\modules\askdoctor\models\Questions;
use app\modules\askdoctor\models\PackageMessage;
use app\modules\askdoctor\models\UserPackage;
use app\modules\askdoctor\models\Specialty;
use app\modules\medbase\models\Clinic;
use yii\widgets\ListView;
use yii\db\Query;
use app\modules\page\models\PageCategory;
use app\modules\page\models\Page;
use kartik\widgets\ActiveForm;
use yii\helpers\Url;
use app\modules\sms\components\Sms;
use app\modules\page\models\PageImages;
use app\modules\medbase\models\Category;

class UserController extends Controller
{
    public function behaviors()
    {
        return [
            'seo' => [
                'class' => MetaBehavior::className(),
                'index' => $this->defaultAction,
            ],
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout', 'signup', 'profile','delete-profile, phone-active'],
                'rules' => [
                    [
                        'actions' => ['signup'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                    [
                        'actions' => ['logout', 'profile','delete-profile, phone-active'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
        ];
    }

    public function beforeAction($action) {

        if (!parent::beforeAction($action)) {
            return false;
        }

        return true;
    }

    public function actions()
    {
        return [
            'auth' => [
                'class' => 'app\modules\user\actions\AuthAction',
                'successCallback' => [$this, 'successCallback'],
            ],
        ];
    }

    public function actionLogin($returnUrl = null) {

        TagDependency::invalidate(Yii::$app->cache, ['Session:'.Yii::$app->session->id]);
        if (\Yii::$app->user->isGuest === false) {
           
           return Yii::$app->getResponse()->redirect(Url::toRoute('/'));
        }

        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {

            return $this->goBack(Url::toRoute($returnUrl));
        } else {
            return $this->render(
                'login',
                [
                    'model' => $model,
                ]
            );
        }
    }

    public function actionLogout() {
        TagDependency::invalidate(Yii::$app->cache, ['Session:'.Yii::$app->session->id]);
        Yii::$app->user->logout();
        return $this->goHome();
    }

    public function actionSignup() {
        TagDependency::invalidate(Yii::$app->cache, ['Session:'.Yii::$app->session->id]);
        $model = new User();
        $model->setScenario('signup');

        $model->load(Yii::$app->request->post());

        if ($model->load(Yii::$app->request->post()) AND $model->validate()) {
            
            $sms_code = $model->randomSmsCode(5);
            
            $model->active        = 1;
            $model->theme_price   = 0;
            $model->user_type     = 1;
            $model->doctor_active = 0;
            $model->generateEmailActiveKey();
            $model->generateAuthKey();
            $model->sms_code      = $sms_code; 
            $model->phone_active  = 0;

            $model->free_message = 10000;

            if ($model->save()){
                UserPackage::createUserPackage($model);
                Yii::$app->getUser()->login($model);

                $text = 'Askdoctor'.
                        '%0A Code: '.$sms_code;

                Yii::$app->sms->send($model->phone,$text);
                if($model->user_type == 1)
                    Yii::$app->session->setFlash('success', Yii::t('app','Registration successfully completed'));
                else
                    Yii::$app->session->setFlash('success', Yii::t('app','Registration successfully completed waiting for moderation'));
                
                return $this->redirect(Url::toRoute('/user/user/profile'));     
            }
        }
            return $this->render('signup', [
                'model' => $model,
            ]);
    }
    
    public function actionActive($key)
    {
        if(Yii::$app->request->get('key') && trim($key) != "")
        { 
            $user = User::find()->where('email_active=:email_active',[':email_active'=>$key])->one();
            if($user){
                $user->scenario = 'active';
                $user->active = 1;
                $user->save();
                if (Yii::$app->getUser()->login($user)) {
                   return $this->goHome();
                }
            }else
                return $this->goHome(); 
        }else {
            return $this->goHome(); 
        }
        return $this->render('active');
    }

    public function actionCompleteRegistration()
    {
        /** @var \app\modules\user\models\User $model */
        $model = Yii::$app->user->identity;

         
        if (intval($model->username_is_temporary) === 1) {
            // reset username
            $model->username = '';
        }
        $model->setScenario('completeRegistration');
        $model->load(Yii::$app->request->post());
        
        if (Yii::$app->request->isAjax && $model->load(Yii::$app->request->post())) {
            Yii::$app->response->format = Response::FORMAT_JSON;
            return ActiveForm::validate($model);
        }
        if (Yii::$app->request->isPost && $model->validate()) {

            $model->username_is_temporary = 0;
            
            $model->save();

            $auth_action = new AuthAction('post-registration', $this);
            return $auth_action->redirect('/');
        } else {
            $this->layout = $this->module->postRegistrationLayout;
            return $this->render('post-registration', [
                'model' => $model,
            ]);
        }
    }

    public function successCallback($client)
    {
        $model = AuthClientHelper::findUserByService($client);
        if (is_object($model) === false){
            // user not found, retrieve additional data
            $client = AuthClientHelper::retrieveAdditionalData($client);
            $attributes = AuthClientHelper::mapUserAttributesWithService($client);
            // check if it is anonymous user
            if (Yii::$app->user->isGuest === true){
                
                $security = Yii::$app->security;
                $model =  User::setAttributesClient($attributes,$client->id);
                
                if (empty($model->username) === true) {
                    // if we doesn't have username - generate unique random temporary username
                    // it will be needed for saving purposes
                    $model->username = $security->generateRandomString(18);
                    $model->username_is_temporary = 1;
                }
                $model->setPassword($security->generateRandomString(16));
                $model->generateAuthKey();
                
                if ($model->validate() === false){
                     
                     if($model->issetUser('email',$model->email)){
                         throw new ErrorException(Yii::t('app', "This service is already binded to another user"));
                     }
                     
                     if($model->issetUser('username',$model->username)){
                        $model->username = $security->generateRandomString(18);
                        $model->username_is_temporary = 1;
                        $model->save();
                      }
                      
                    if (count($model->errors) > 0) {
                        throw new ErrorException(Yii::t('app', "Temporary error signing up user "));
                    }
                      $model->save();
                }else
                      $model->save();
            } else {
                // non anonymous - link to existing account
                /** @var \app\modules\user\models\User $model */
                $model = Yii::$app->user->identity;
            }
            
            $service = new UserService();
            $service->service_type = $client->className();
            $service->service_id = '' . $attributes['service']['service_id'];
            $service->user_id = $model->id;
            if ($service->save() === false) {
                throw new ErrorException(Yii::t('app', "Temporary error saving social service"));
            }

        } elseif (Yii::$app->user->isGuest === false) {
            // service exists and user logged in
            // check if this service is binded to current user
            
            if ($model->id == Yii::$app->user->id){
                $service_disable = UserService::find()->where(
                    'user_id=:id AND service_type=:service_type',
                    [
                        ':id'=>$model->id,
                        ':service_type'=>$client->className(),
                    ]
                )->one();
                $service_disable->delete();
                
            }
            if ($model->id != Yii::$app->user->id) {
                throw new ErrorException(Yii::t('app', "This service is already binded to another user"));
               } 
        }
        TagDependency::invalidate(Yii::$app->cache, ['Session:'.Yii::$app->session->id]);
          if(Yii::$app->user->isGuest === true)
            Yii::$app->user->login($model, 86400);
           
          
        
        
        if ($model->username_is_temporary == 1 || empty($model->email) || $model->user_type == 0) {
            // show post-registration form
            $this->layout = $this->module->postRegistrationLayout;
             
            $model->setScenario('completeRegistration');

            echo $this->render('post-registration', [
                'model' => $model,
            ]);
            Yii::$app->end();
            return;
        }
    }

    public function actionRequestPasswordReset()
    {
        // if user not guest
        if(!Yii::$app->user->isGuest)
          $this->redirect(['/default/index']);

        $model        = new PasswordResetRequestForm();

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {

            $user           = User::find()->where(['phone'=>$model->phone])->one();
            $password_code  = $user->randomSmsCode(5);
            $user->scenario            = 'password_hash';
            $user->password_reset_date = date('Y-m-d H:i',strtotime("+5 minutes"));
            $user->password_code       = $password_code;

            if($user->save()){

                if(Yii::$app->sms->send($user->phone,Yii::t('app','New password code:').' '.$password_code)) {
                    Yii::$app->getSession()->setFlash(
                    'success',
                    Yii::t('app', 'Send code sms success')
                    );

                    return $this->redirect(['/user/user/password-code','id'=>$user->id]);
                }
            }else

                Yii::$app->getSession()->setFlash(
                    'error',
                    Yii::t('app', 'Sorry user save error ')
                );
        }

        return $this->render('requestPasswordResetToken', [
            'model' => $model,
        ]);
    }

    public function actionPasswordCode($id)
    {
        $user           = User::find()->where(['id'=>$id])->one();
        $model        = new PhoneActive();

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if($model->code == $user->password_code) {
                if(strtotime($user->password_reset_date) > strtotime(date("Y-m-d H:i"))) {
                    $user->scenario  = 'password_code';
                    $new_pass        = $user->randomSmsCode(9);
                    $user->setPassword($new_pass);
                    
                    if($user->save()){
                        if(Yii::$app->sms->send($user->phone,Yii::t('app','New password').': '.$new_pass)) {
                            Yii::$app->getSession()->setFlash(
                            'success',
                            Yii::t('app', 'Send new password success')
                            ); 
                        }else
                            Yii::$app->getSession()->setFlash(
                            'error',
                            Yii::t('app', 'Sorry, error sms sending')
                        );
                    }else{
                        Yii::$app->getSession()->setFlash(
                        'error',
                        Yii::t('app', 'Sorry, error saving')
                        );
                        }    
                }else
                    Yii::$app->getSession()->setFlash(
                    'error',
                    Yii::t('app', 'Code time out')
                    );
                }else
                Yii::$app->getSession()->setFlash(
                'error',
                Yii::t('app', 'Incorrect code.')
                );
        }

        return $this->render('passwordCode', [
            'model' => $model,
        ]);
    }

    public function actionPhoneActive()
    {
        $user         = User::findIdentity(Yii::$app->user->id);
        $model        = new PhoneActive();

        if(Yii::$app->user->isGuest || $user->phone_active == 1)
            return $this->goHome();
        
        if(isset($_POST['send_sms']) AND $_POST['send_sms'] == 1)
        {   
            $sms_code = $user->randomSmsCode(5);
            $user->scenario = 'sms_code';
            $user->sms_code = $sms_code; 
            
            if($user->save() AND Yii::$app->sms->send($user->phone,'Code: '.$sms_code))
                    Yii::$app->getSession()->setFlash(
                        'success',
                        Yii::t('app', 'success send sms')
                    );
            else
                    Yii::$app->getSession()->setFlash(
                        'error',
                        Yii::t('app', 'Error send sms')
                    );        
            
        }else if ($model->load(Yii::$app->request->post()) && $model->validate()) {
           
           if($model->code == $user->sms_code)
           {
                $user->scenario = 'phone_active';
                $user->phone_active = 1;
                if($user->save())
                {
                    Yii::$app->getSession()->setFlash(
                        'success',
                        Yii::t('app', 'success active phone number')
                    );
                    return Yii::$app->getResponse()->redirect('/user/user/profile');
                }else
                    Yii::$app->getSession()->setFlash(
                        'error',
                        Yii::t('app', 'Error save user data')
                    );
                
           }else
           {
                Yii::$app->getSession()->setFlash(
                    'error',
                    Yii::t('app', 'Code invalid')
                ); 
           }
        }
        return $this->render('phoneActive', [
            'model' => $model,
        ]);
    }

    public function actionResetPassword($token)
    {

        try {
            $model = new ResetPasswordForm($token);
        } catch (InvalidParamException $e) {
            throw new BadRequestHttpException($e->getMessage());
        }

        if ($model->load(Yii::$app->request->post()) && $model->validate() && $model->resetPassword()) {
            Yii::$app->getSession()->setFlash(
                'success',
                Yii::t('app', 'New password was saved.')
            );

            return $this->goHome();
        }

        return $this->render('resetPassword', [
            'model' => $model,
        ]);
    }

    public function actionView($id)
    {
        $model = $this->findModel($id);
        $files = UserFile::find()->where('user_id=:user_id',[':user_id'=>$model->id])->all();
        $user = User::findIdentity(Yii::$app->user->id);

        $query_page = Page::find()->where(['user_id'=>$model->id,'published'=>1]);

        Yii::$app->view->registerMetaTag([
                'name' => 'description',
                'content' => $model->description,
            ]);
        Yii::$app->view->registerMetaTag([
                'name' => 'keywords',
                'content' => $model->keywords,
            ]); 
        
        $category = PageCategory::find()->where(['slug'=>'post'])->one();
        $page = Page::find()->where(
                           [
                            'published'   =>1,
                            'category_id' =>$category->id,
                            'user_id'     => $model->id
                           ]);
                          
        $dataProvider = new ActiveDataProvider([
        'query' =>$page,
        'pagination' => 
            [
               'pageSize' =>3,
            ],
        ]);        


        if($model->user_type == 2) {
            $view = 'view-doctor';

            $doctorQuery = User::find()
                ->where(['specialty_id'=>$model->specialty_id])
                ->doctor();

            $doctorQuery->andWhere('id !='.$model->id);

        }else
            $view = 'view-user';

        return $this->render(
            $view,
            [
                'model'        => $model,
                'files'        => $files,
                'user'         => $user,
                'query_page'   => $query_page,
                'doctorQuery'  => $doctorQuery
            ]
        );
    }
    
    public function actionList() {

        $request   = Yii::$app->request;
        $user      = User::findIdentity(Yii::$app->user->id);
        $specialty = Specialty::getListData();
        $clinics   = Clinic::getListData();
        $citys     = City::getListDataCityArea();

        $page = Page::find()->where('slug="user-list"')->one();

        $query = User::find()
                       ->where(['user_type'=>2,'status'=>10,'doctor_active'=>1])
                       ->orderBy(['last_login'=>SORT_DESC]);

        if($request->get('specialty')){
            $specialty_id = str_replace(";",",",$request->get('specialty'));
            $query->andWhere('specialty_id in('.$specialty_id.')');
        }

        if($request->get('clinic')){
            $clinic_id = str_replace(";",",",$request->get('clinic'));
            $query->andWhere('clinic_id in('.$clinic_id.')');
        }

        if($request->get('area')){

            $area_id = str_replace(";",",",$request->get('area'));
            $clinic_area = Clinic::find()->where('area_id in('.$area_id.')')->all();

            if($clinic_area){
                $clinic_area_id = [];
                foreach($clinic_area as $c)
                    $clinic_area_id[] = $c->id;
            }else
                $clinic_area_id[] = -1;
            $clinic_area_id = implode(',', $clinic_area_id);
            $query->andWhere('clinic_id in('.$clinic_area_id.')');
        }


        if($request->get('service')){

            $service__id = str_replace(";",",",$request->get('service'));

            $clinic_service = Clinic::find()
                        ->leftJoin('clinicCategory','"clinicCategory".clinic_id = "clinic".id')
                        ->where(' "clinicCategory".category_id in('.$service__id.')')
                        ->all();

            $clinic_service_id = [];
            foreach($clinic_service as $c)
                $clinic_service_id[] = $c->id;

            $clinic_service_id = implode(',', $clinic_service_id);
            $query->andWhere('clinic_id in('.$clinic_service_id.')');

        }

        if($request->get('analysis')){

            $analysis__id = str_replace(";",",",$request->get('analysis'));

            $clinic_analysis = Clinic::find()
                ->leftJoin('clinicCategory','"clinicCategory".clinic_id = "clinic".id')
                ->where(' "clinicCategory".category_id in('.$analysis__id.')')
                ->all();

            $clinic_analysis_id = [];
            foreach($clinic_analysis as $c)
                $clinic_analysis_id[] = $c->id;

            $clinic_analysis_id = implode(',', $clinic_analysis_id);
            $query->andWhere('clinic_id in('.$clinic_analysis_id.')');

        }

        $_this_date = date('Y-m-d H:i:s', strtotime('-2 minutes'));

        return $this->render('user-list',
            [
             'query'     => $query,
             'specialty' => $specialty,
             'clinics'   => $clinics,
             'citys'     => $citys,
             'page'     => $page,
            ]
        );
    }
    
    public function actionDeleteProfile() {

        $model = User::findIdentity(Yii::$app->user->id);
        
        if(Yii::$app->request->get() && (int)Yii::$app->request->get('deleteProfile') == 1) {
            $model->scenario = 'status';
            $model->status = 5;
            $model->save();
            return $this->redirect('/'); 
        }
        
        return $this->render(
            'deleteProfile',
            [
                'model'  => $model,
            ]
        );
    }

    public function actionUploadImage()
    {
       if(Yii::$app->request->post())
        {
           $model = User::findIdentity(Yii::$app->user->id);
           $model->scenario = 'image';

           if($model->validate()){

               if($model->image = $model->uploadFile()){
                     $model->deleteImage();
                     $model->save();
                     return true;
                 }
           }else
                 return ActiveForm::validate($model);
        }
        Yii::$app->end();
    }
    
    public function actionUserImage()
    {
       if(Yii::$app->request->isAjax)
        {
            $model = User::findIdentity(Yii::$app->user->id);
            return $model->getThumbnail('270','270');
        }
        Yii::$app->end();
    }
    
    public function actionProfileUpdate()
    {
        $model = User::find()->where(['id'=>Yii::$app->user->id])->multilingual()->one();
        $model->scenario = 'updateProfile';

        if($model->isDoctor())
            $view = 'profileDoctorUpdate';
        else
            $view = 'profileUpdate';

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {

            if ($model->save()) {
                Yii::$app->session->setFlash('success', Yii::t('app', 'Your profile has been updated'));
                return $this->refresh();
            } else {
                Yii::$app->session->setFlash('error', Yii::t('app', 'Internal error'));
            }
        }
       
       return $this->render(
            $view,
            [
                'model' => $model,
                'services' => ArrayHelper::map($model->services, 'id', 'service_type'),
            ]
        );
    }

    public function actionProfile() {

        $model = User::findIdentity(Yii::$app->user->id);

        $queryMedHistory = MedHistory::find()
            ->where(['patient_id'=>$model->id])
            ->orderBy(['date_created'=>SORT_DESC]);

        // ------------------  active question query ------------------
        $active_question  = QuestionsTheme::find();
        $active_question->select = [
            '`questions_theme`.*',
            'IF(questions.is_view = 0 AND questions.user_type != '.$model->user_type.', 1,0) as new_q'
        ];

        $active_question->leftJoin('questions', 'questions.theme_id = questions_theme.id');
        if($model->user_type == 1) {
            $active_question->where(
                'questions_theme.status  in (0, 1, 2, 4, 5) AND
                     questions_theme.user_id   ='.$model->id.' AND
                     questions.id              = (SELECT MAX(q.id) FROM questions q WHERE q.theme_id = `questions_theme`.id)'
            );
        }elseif($model->user_type == 2) {
            $active_question->where(
                'questions_theme.status in(1,5) AND
                 questions_theme.doctor_id = '.$model->id.' AND
                 questions.id              = (SELECT MAX(q.id) FROM questions q WHERE q.theme_id = `questions_theme`.id)'
            );
        }
        $active_question->orderBy([
            'new_q'=> SORT_DESC,
            'questions.created'=> SORT_DESC,
        ]);

        // ------------------  Doctor reception query ------------------


        if($model->user_type == 1){
            $doctorReceptionCondition = ['user_id'=>$model->id];
        }else{
            $doctorReceptionCondition = ['doctor_id'=>$model->id];
        }

        $doctorReceptionQuery = DoctorReception::find()
                ->where($doctorReceptionCondition)
                ->orderBy(['date_created'=>SORT_DESC]);

        // ------------------  Doctor page query ------------------

        $queryPage = Page::find()->where(['user_id'=>$model->id]);


       // ------------------  Doctor page query ------------------
        $queryNotification = Notification::find()
            ->where(['user_id'=>$model->id])
            ->orderBy(['date_created'=>SORT_DESC]);

        return $this->render('profile',
            [
                'model'                => $model,
                'queryMedHistory'      => $queryMedHistory,
                'active_question'      => $active_question,
                'queryPage'            => $queryPage,
                'doctorReceptionQuery' => $doctorReceptionQuery,
                'queryNotification'    => $queryNotification,
            ]
        );
    }

    public function actionProfilEdit()
    {
        $model = User::find()->where(['id'=>Yii::$app->user->id])->multilingual()->one();
        $model->scenario = 'profileEdit';

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->save())
                return true;
            else
                return false;
        }

        Yii::$app->end();
    }

    public function actionChangePassword()
    {
        $model = User::findIdentity(Yii::$app->user->id);
        if (is_null($model)) {
            throw new NotFoundHttpException;
        }
        $model->scenario = 'changePassword';
        if (Yii::$app->request->isPost) {
            $model->load(Yii::$app->request->post());
            $formIsValid = $model->validate();
            $passwordIsValid = $model->validatePassword($model->password);
            if (!$passwordIsValid) {
                $model->addError('password', Yii::t('app', 'Wrong password'));
            }
            if ($formIsValid && $passwordIsValid) {
                $model->setPassword($model->newPassword);
                if ($model->save(true, ['password_hash'])) {
                    Yii::$app->session->setFlash('success', Yii::t('app', 'Password has been changed'));
                    return $this->refresh();
                } else {
                    Yii::$app->session->setFlash('error', Yii::t('app', 'Internal error'));
                }
            }
        }
        return $this->render('change-password', ['model' => $model]);
    }

    protected function findModel($id)
    {
        if (($model = User::find()->where(['id'=>$id])->one()) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}


