<?php

namespace app\modules\user\models;

use Yii;
use yii\base\Model;
use yii\helpers\Html;
use yii\helpers\Url;
use app\modules\askdoctor\models\UserPackage;

/**
 * RegistrationForm is the model behind the login form.
 */
class RegistrationForm extends Model
{
    public $username;
    public $email;
    public $password;
    public $confirmPassword;
    public $user_type;
    public $theme_price;

    private $user = false;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['username', 'email', 'password', 'confirmPassword'], 'required'],
            ['user_type', 'required','message'=>Yii::t('app', 'select the type of user')], 
            ['email', 'email'],
            ['password', 'string', 'min' => 8],
            ['confirmPassword', 'compare', 'compareAttribute' => 'password'],
            ['theme_price','safe'],
        ];
    }


    public function isDoctor()
    {
        if ($this->hasErrors() === false) {
            if($this->user_type == 2)
            {
                if(trim($this->theme_price) == "")
                    $this->addError('theme_price','Error empty Theme price ');    
            }
        }
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'username' => Yii::t('app', 'Username'),
            'email' => Yii::t('app', 'E-mail'),
            'password' => Yii::t('app', 'Password'),
            'confirmPassword' => Yii::t('app', 'Confirm Password'),
        ];
    }

    /**
     * Signs user up.
     *
     * @return User|null the saved model or null if saving fails
     */
    public function signup()
    {
        if ($this->validate() === true) {
            $user = new User;
            
            $user->setScenario('signup');
            
            $user->username    = $this->username;
            $user->password    = $this->password;
            $user->email       = $this->email;
            $user->user_type   = $this->user_type;
            $user->theme_price = $this->theme_price;
            $user->active      = 1;
            
            $user->generateEmailActiveKey();
            $user->generateAuthKey();
            if ($user->save() === false) {
                $this->addErrors($user->errors);
                //return null;
            }else{
                  $userPackage = new UserPackage;
                  $userPackage->user_id = $user->id;
                  $userPackage->save();
            }
           // return $user;
        }

        //return null;

    }

    /**
     * Finds user by [[username]]
     *
     * @return User|null
     */
    private function getUser()
    {
        if ($this->user === false) {
            $this->user = User::findByUsername($this->username);
        }
        return $this->user;
    }
    
    public function sendMessageToEmail($email,$key)
    {   $showMail = Yii::$app->mailer
                ->compose()
                ->setTo($email)
                ->setFrom(Yii::$app->getModule('core')->emailConfig['mailFrom'])
                ->setSubject("Active for E-mail")
                 ->setHtmlBody('<a href="http://ascdoctor.uz/user/user/active?key='.$key.'" >Active click</a>')
                ->send();
               
    }
}?>

