<?php

use yii\helpers\Html;
use app\backend\components\ActionColumn;
use kartik\dynagrid\DynaGrid;
use kartik\icons\Icon;
use \devgroup\JsTreeWidget\ContextMenuHelper;
use \app\backend\components\Helper;
use kartik\tree\TreeView;
use app\modules\medbase\models\Category;
use \kartik\grid\GridView;
use \kartik\popover\PopoverX;
use kartik\grid\EditableColumn;
use kartik\editable\Editable;
use yii\helpers\Url;
use kartik\grid\SerialColumn;
use app\modules\user\models\User;
use \app\modules\medbase\models\Clinic;
use yii\web\JsExpression;
use app\modules\user\models\UserAppLog;
use yii\helpers\Json;

$this->title = Yii::t('app', 'User app log');
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="row">
<div class="col-sm-12">
<?

$columns = [
    ['class'=>'kartik\grid\SerialColumn'],
    [
        'class' => 'kartik\grid\DataColumn',
        'attribute' => 'id',
        'options' => [
            'width' => '40px',
        ],
    ],
    [
        'class' => 'kartik\grid\DataColumn',
        'attribute' => 'app_type',
        'value'=>function($data){
            return UserAppLog::getAppTypeLabel($data->app_type);
        },
        'filterType'=>GridView::FILTER_SELECT2,
        'filter'=>[
            UserAppLog::APP_WEB=> UserAppLog::getAppTypeLabel(UserAppLog::APP_WEB),
            UserAppLog::APP_IOS=> UserAppLog::getAppTypeLabel(UserAppLog::APP_IOS),
            UserAppLog::APP_ANDROID=> UserAppLog::getAppTypeLabel(UserAppLog::APP_ANDROID)
        ],
        'filterWidgetOptions'=>[
            'pluginOptions' => ['allowClear' => true],
        ],
        'filterInputOptions' => ['placeholder' => Yii::t('app','Action')],
        'format'=>'raw',
    ],
    [
        'class' => 'kartik\grid\DataColumn',
        'attribute' => 'user_id',
        'value'=>function($data) {
            return $data->getUser()->one()->first_name.' '.$data->getUser()->one()->last_name;
        },
        'filterType'=>GridView::FILTER_SELECT2,
        'filterWidgetOptions'=>[

            'pluginOptions' => [
                'allowClear' => true,
                'minimumInputLength' => 3,
                'language' => [
                    'errorLoading' => new JsExpression("function () { return 'Waiting for results...'; }"),
                ],
                'ajax' => [
                    'url' => Url::to(['/user/backend-user/ajax-list-data']),
                    'dataType' => 'json',
                    'data' => new JsExpression('function(params) { return {q:params.term}; }')
                ],
                'escapeMarkup' => new JsExpression('function (markup) { return markup; }'),
                'templateResult' => new JsExpression('
                                function(data) {
                                        return data.id+" "+data.first_name+" "+data.last_name;
                                    }
                                '),
                'templateSelection' => new JsExpression('function (data) {
                                    return data.id;
                                }'),
            ],
        ],
        'filterInputOptions' => ['placeholder' => 'Type a position'],
        'format'=>'raw',
    ],
    [
        'class' => 'kartik\grid\DataColumn',
        'attribute' => 'date_created',
        'options' => [
            'width' => '100px',
        ],
        'filterType'=>GridView::FILTER_DATE,
        'filterWidgetOptions'=>[
            'pluginOptions' => [
                'allowClear' => true,
                'format' => 'yyyy-m-dd',
                'todayHighlight' => true,
                'autoclose' => true,
                'orientation' => 'auto',
                //'container' => '#date_created-kvdate'
            ],
        ],
        'filterInputOptions' => ['placeholder' => Yii::t('app','Date start')],
        'format'=>'raw',
    ],
];


echo GridView::widget([
    'dataProvider' => $dataProvider,
    'filterModel'  => $searchModel,
    'columns' => $columns,
    //'containerOptions' => ['style'=>'overflow: visible'], // only set when $responsive = false
    'floatOverflowContainer'=> false,
    'pjax' => false,
    'bordered' => true,
    'persistResize'=>true,
    'striped' => true,
    'condensed' => false,
    'responsive' => true,
    'hover' => true,
    'floatHeader' => false,
    'floatHeaderOptions' => ['scrollingTop' => 10],
    'showPageSummary' => true,
    'panel' => [
        'type' => GridView::TYPE_DEFAULT,
        'after' => '',
    ],
]);


?>

</div>
</div>
