<?php

use yii\helpers\Html;
use app\backend\components\ActionColumn;
use kartik\dynagrid\DynaGrid;
use kartik\icons\Icon;
use \devgroup\JsTreeWidget\ContextMenuHelper;
use \app\backend\components\Helper;
use app\modules\medbase\models\Category;
use \kartik\grid\GridView;
use \kartik\popover\PopoverX;
use kartik\grid\EditableColumn;
use kartik\editable\Editable;
use yii\helpers\Url;
use kartik\grid\SerialColumn;
use app\modules\user\models\User;
use \app\modules\medbase\models\Clinic;
use yii\web\JsExpression;
use app\modules\askdoctor\models\Specialty;
use app\backend\widgets\BackendWidget;
use app\modules\askdoctor\models\QuestionsTheme;

$this->title = Yii::t('app', 'User question statistics');
$this->params['breadcrumbs'][] = $this->title;
?>

<div class="row ">
    <div class="col-sm-12">

        <?php
        BackendWidget::begin(
            [
                'icon'   => 'area-chart',
                'title'  => Yii::t('app','User question statistics'),
            ]
        );
        ?>

        <?
        $columns = [
            ['class'=>'kartik\grid\SerialColumn'],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'id',
                'options' => [
                    'width' => '40px',
                ],
                'value'=>function($data) {
                    return $data->id.' '.$data->first_name.' '.$data->last_name;
                },
                'filterType'=>GridView::FILTER_SELECT2,
                'filterWidgetOptions'=>[

                    'pluginOptions' => [
                        'allowClear' => true,
                        'minimumInputLength' => 3,
                        'language' => [
                            'errorLoading' => new JsExpression("function () { return 'Waiting for results...'; }"),
                        ],
                        'ajax' => [
                            'url' => Url::to(['/user/backend-user/ajax-list-data']),
                            'dataType' => 'json',
                            'data' => new JsExpression('function(params) { return {q:params.term}; }')
                        ],
                        'escapeMarkup' => new JsExpression('function (markup) { return markup; }'),
                        'templateResult' => new JsExpression('
                                function(data) {
                                        return data.id+" "+data.first_name+" "+data.last_name;
                                    }
                                '),
                        'templateSelection' => new JsExpression('function (data) {
                                    return data.id;
                                }'),
                    ],
                ],
                'filterInputOptions' => ['placeholder' => 'Type a position'],
                'format'=>'raw',
            ],

            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'clinic_id',
                'value'=>function($data){
                    return $data->getClinic()->name;
                },
                'filterType'=>GridView::FILTER_SELECT2,
                'filter'=>Clinic::getListData(),
                'filterWidgetOptions'=>[
                    'pluginOptions' => ['allowClear' => true],
                ],
                'filterInputOptions' => ['placeholder' => Yii::t('app','Clinic')],
                'format'=>'raw',
            ],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'specialty_id',
                'value' => function ($data) {
                    return $data->getSpecialty()->name;
                },
                'filterType'=>GridView::FILTER_SELECT2,
                'filter'=>Specialty::getListData(),
                'filterWidgetOptions'=>[
                    'pluginOptions' => ['allowClear' => true],
                ],
                'filterInputOptions' => ['placeholder' => Yii::t('app','Specialty')],
                'format'=>'raw',
            ],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'active',
                'header'=>'Активные темы',
                'value' => function ($data) {
                    return $data->getQuestionCount(QuestionsTheme::STATUS_ACTIVE);
                },
                'pageSummary'=>true






            ],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'answered',
                'header'=>'Отвеченные',
                'value' => function ($data) {
                    return $data->getQuestionCount(QuestionsTheme::STATUS_ANSWERED);
                },
                'pageSummary'=>true
            ],
            [
                'class' => 'kartik\grid\DataColumn',
                'attribute' => 'closed',
                'header'=>'Закрытые темы',
                'value' => function ($data) {
                    return $data->getQuestionCount(QuestionsTheme::STATUS_CLOSED);
                },
                'pageSummary'=>true
            ],


        ];


        echo GridView::widget([
            'dataProvider' => $dataProvider,
            'filterModel'  => $searchModel,
            'columns' => $columns,
            'containerOptions' => ['style'=>'overflow: visible'], // only set when $responsive = false
            'floatOverflowContainer'=> false,
            'pjax' => false,
            'bordered' => true,
            'persistResize'=>true,
            'striped' => true,
            'condensed' => false,
            'responsive' => true,
            'hover' => true,
            'floatHeader' => false,
            'floatHeaderOptions' => ['scrollingTop' => 10],
            'showPageSummary' => true,
            'panel' => [
                'type' => GridView::TYPE_DEFAULT,
                'after' =>  '',
            ],
        ]);


        ?>

        <?php BackendWidget::end(); ?>
    </div>
</div>