<?php

/**
 * @var $dataProvider \yii\data\ActiveDataProvider
 * @var $searchModel \app\components\SearchModel
 * @var $this \yii\web\View
 */

use app\backend\components\ActionColumn;
use kartik\dynagrid\DynaGrid;
use kartik\helpers\Html;
use kartik\icons\Icon;
use kartik\editable\Editable;
use kartik\popover\PopoverX;
use app\modules\user\models\User;
use app\modules\medbase\models\Clinic;

$this->title = Yii::t('app', 'Users');
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="user-index">
    <?=DynaGrid::widget([
            'options' => [
                'id' => 'users-grid',
            ],
            'columns' => [
                [
                    'class' => \kartik\grid\CheckboxColumn::className(),
                    'options' => [
                        'width' => '10px',
                    ],
                ],
                [
                    'class' => 'yii\grid\DataColumn',
                    'attribute' => 'id',
                    'options' => [
                        'width' => '70px',
                     ],
                ],         
                'username',
                'first_name',
                'last_name',
                [
                        'class' => \kartik\grid\EditableColumn::className(),
                        'attribute' => 'status',
                        'options' => [
                            'width' => '100px',
                         ],
                        'editableOptions' => [
                            'data' => [0=>Yii::t('app', 'Deleted'),10=>Yii::t('app', 'Active'),5=>Yii::t('app', 'Удалить')],
                            'inputType' => 'dropDownList',
                            'placement' => 'left',
                            'formOptions' => [
                                'action' => 'update-editable',
                             ],
                           
                        ],
                        'format' => 'raw',
                        'filter'=>[0=>Yii::t('app', 'Deleted'),10=>Yii::t('app', 'Active'),5=>Yii::t('app', 'Удалить')], 
                         'value' => function ($data) {
                            if ($data === null || $data->status === null) {
                                return null;
                            }
                            if ($data->status == 0) {
                                $label_class = 'label-default';
                                $value = Yii::t('app', 'Deleted');
                            }elseif ($data->status == 10) {
                                $label_class = 'label-success';
                                $value = Yii::t('app', 'Active');
                            }elseif ($data->status == 5) {
                                $label_class = 'label-danger';
                                $value = Yii::t('app', 'Удалить');
                            }    
                            return Html::tag(
                                'span',
                                Yii::t('app', $value),
                                ['class' => "label $label_class"]
                            );
                        },
                         
                    ],
                [
                        'class' => \kartik\grid\EditableColumn::className(),
                        'attribute' => 'sort',
                        'editableOptions' => [
                        'inputType' => Editable::INPUT_TEXT,
                        'formOptions' => [
                                            'action' => 'update-user',
                                         ],
                        'placement' => PopoverX::ALIGN_RIGHT,
                        ],
                    ],
                'create_time:datetime',
                [
                    'class' => ActionColumn::className(),
                    'options' => [
                        'width' => '95px',
                    ],
                    'buttons' => [
                        [
                            'url' => 'update',
                            'icon' => 'pencil',
                            'class' => 'btn-primary',
                            'label' => Yii::t('app', 'Edit'),

                        ],
                        [
                            'url' => 'delete',
                            'icon' => 'trash-o',
                            'class' => 'btn-danger',
                            'options' => [
                                'data-action' => 'delete',
                            ],
                            'label' => Yii::t('app', 'Delete'),
                        ],
                    ],
                ],
            ],
            'theme' => 'panel-default',
            'gridOptions'=>[
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'hover' => true,
                'panel' => [
                    'heading' => Html::tag('h3', $this->title, ['class' => 'panel-title']),
                    'after' => Html::a(
                        Icon::show('plus') . Yii::t('app', 'Add'),
                        ['/user/backend-user/update'],
                        ['class' => 'btn btn-success']
                    ) . \app\backend\widgets\RemoveAllButton::widget([
                        'url' => '/user/backend-user/remove-all',
                        'gridSelector' => '.grid-view',
                        'htmlOptions' => [
                            'class' => 'btn btn-danger pull-right'
                        ],
                    ]),

                ],
            ]
        ]);
    ?>
</div>








