<?php

/**
 * @var $assignments array
 * @var $model \app\modules\user\models\User
 * @var $this \yii\web\View
 */

use app\backend\widgets\BackendWidget;
use kartik\helpers\Html;
use kartik\icons\Icon;
use app\backend\components\ActiveForm;
use kartik\widgets\FileInput;
use app\modules\core\models\Language;
use app\modules\askdoctor\models\QuestionsTheme;
use app\modules\askdoctor\models\Specialty;
use app\modules\medbase\models\Clinic;

$this->title = $model->isNewRecord ? Yii::t('app', 'Create') : Yii::t('app', 'Update');
$this->params['breadcrumbs'] = [
    ['label' => Yii::t('app', 'Users'), 'url' => ['index']],
    $this->title
];

?>
<?php $this->beginBlock('submit'); ?>
<div class="form-group no-margin">
    <?=
    Html::a(
        Icon::show('arrow-circle-left') . Yii::t('app', 'Back'),
        Yii::$app->request->get('returnUrl', ['/user/backend-user/index']),
        ['class' => 'btn btn-danger']
    )
    ?>
    <?php if ($model->isNewRecord): ?>
        <?=
        Html::submitButton(
            Icon::show('save') . Yii::t('app', 'Save & Go next'),
            [
                'class' => 'btn btn-success',
                'name' => 'action',
                'value' => 'next',
            ]
        )
        ?>
    <?php endif; ?>
    <?= Html::submitButton(
        Icon::show('save') . Yii::t('app', 'Save & Go back'),
        [
            'class' => 'btn btn-warning',
            'name' => 'action',
            'value' => 'back',
        ]
    ); ?>
    <?=
    Html::submitButton(
        Icon::show('save') . Yii::t('app', 'Save'),
        [
            'class' => 'btn btn-primary',
            'name' => 'action',
            'value' => 'save',
        ]
    )
    ?>

</div>
<?php $this->endBlock(); ?>

    <?php $form = ActiveForm::begin(
        ['options' => ['enctype' => 'multipart/form-data']]
        ); ?>

    <section id="widget-grid">
        <div class="row">
            
            <article class="backend-edit-grid col-lg-6 col-md-6 col-ms-6 col-xs-12">
                <?php
                    BackendWidget::begin(
                        [
                            'icon' => 'FileInput',
                            'title'=> Yii::t('app', 'Image'),
                            'footer' => $this->blocks['submit']
                        ]
                    );
                ?>
                
                <? 
                    $options = [];
                        if ($model->isNewRecord === false) {
                            $this->registerCss('span.file-input > div.file-preview {display:block;}');
                            $this->registerCss('.file-preview-frame {width: 95%;}');
                            
                            $this->registerCss('.file-preview img {max-height:200px;}');
                            $options = ['initialPreview' => [Html::img($model->image)]];
                        }
                    echo $form->field($model, 'image')->widget(
                            FileInput::classname(),
                            [
                                'options' => ['accept' => 'image/*'],
                                'pluginOptions' => $options,
                            ]
                );?>

                <?php BackendWidget::end(); ?>  
                <br>
                <?php
                    BackendWidget::begin(
                        [
                            'icon' => 'cogs',
                            'title'=> Yii::t('app', 'Settings'),
                            'footer' => $this->blocks['submit']
                        ]
                    );
                ?>

                    <?= $form->field($model, 'status')->dropDownList($model->getStatuses()) ?>
                    <?= $form->field($model, 'email_active')->dropDownList([
                                   1=>Yii::t('app', 'Active'),
                                   0=>Yii::t('app', 'Inactive'
                                   )]) ?>

                    <?=
                        app\widgets\MultiSelect::widget([
                            'items' => \yii\helpers\ArrayHelper::map(
                                \Yii::$app->getAuthManager()->getRoles(),
                                'name',
                                function ($item) {
                                    return $item->name . (strlen($item->description) > 0
                                        ? ' [' . $item->description . ']'
                                        : '');
                                }
                            ),
                            'selectedItems' => $model->isNewRecord ? [] : $assignments,
                            'ajax' => false,
                            'name' => 'AuthAssignment[]',
                            'label' => Yii::t('app', 'Assignments'),
                        ]);
                    ?>
                <?php BackendWidget::end(); ?>
            </article>

            <article class="backend-edit-grid col-lg-6 col-md-6 col-ms-6 col-xs-12">
                <?php
                    BackendWidget::begin(
                        [
                            'icon' => 'user',
                            'title'=> Yii::t('app', 'Profile'),
                            'footer' => $this->blocks['submit']
                        ]
                    );
                ?>
                
                <?= $form->field($model, 'first_name')->textInput(['maxlength' => 255, 'autocomplete' => 'off']) ?>
                <?= $form->field($model, 'last_name')->textInput(['maxlength' => 255, 'autocomplete' => 'off']) ?>
                <?= $form->field($model, 'middle_name')->textInput(['maxlength' => 255, 'autocomplete' => 'off']) ?>
                <?= $form->field($model, 'username')->textInput(['maxlength' => 255, 'autocomplete' => 'off']) ?>
                <?= $form->field($model, 'password')->textInput(['maxlength' => 255]) ?>
                <?= $form->field($model, 'email')->textInput(['maxlength' => 255]) ?>
                <?= $form->field($model, 'phone')->textInput(['maxlength' => 255]) ?>

                <?=$form->field($model, 'city_id')->widget(\kartik\widgets\Select2::classname(), [
                    'data' => \app\modules\regions\models\City::getListData(),
                    'language' => 'ru',
                    'options' => ['placeholder' => 'Select a city...'],
                    'pluginOptions' => [
                        'allowClear' => true
                    ],
                ]);
                ?>
                
                <?php BackendWidget::end(); ?>   
            </article>

            <article class="backend-edit-grid col-lg-6 col-md-6 col-ms-6 col-xs-12">
                <?php
                BackendWidget::begin(
                    [
                        'icon' => 'user',
                        'title'=> Yii::t('app', 'social'),
                        'footer' => $this->blocks['submit']
                    ]
                );
                ?>
                <?= $form->field($model, 'facebook')->textInput(['maxlength' => 255]) ?>
                <?= $form->field($model, 'twitter')->textInput(['maxlength' => 255]) ?>
                <?= $form->field($model, 'instagram')->textInput(['maxlength' => 255]) ?>


                <?php BackendWidget::end(); ?>
            </article>

            <article class="backend-edit-grid col-lg-6 col-md-6 col-ms-6 col-xs-12">
                <br>
                <?php
                        BackendWidget::begin(
                            [
                                'icon' => 'user',
                                'title'=> Yii::t('app', 'Profile'),
                                'footer' => $this->blocks['submit']
                            ]
                        );
                    ?>
                    <div class="container col-xs-12 col-sm-12 col-md-12 col-lg-12">
                        <div class="row">
                            <ul class="nav nav-tabs" >
                             <?
                                 foreach(Language::getAllLanguages('url') as $lang_tab_title) {
                                    ($lang_tab_title == substr(Yii::$app->language,0,2))?$class = "active":$class = " ";
                                   echo '<li style="text-transform: uppercase;" class="text-center '.$class.'"><a href="#'.$lang_tab_title.'" data-toggle="tab">'.$lang_tab_title.'</a>';
                                 }
                            ?>
                            </ul>

                            <div class="tab-content ">
                            <br />
                            <?
                                 foreach(Language::getAllLanguages('url') as $lang_tab_title)
                                 {
                                  ($lang_tab_title == substr(Yii::$app->language,0,2))?$class = "active":$class = " ";
                                  echo '<div class="tab-pane  '.$class.'" id="'.$lang_tab_title.'">';
                                      ($lang_tab_title != Language::getDefaultLang()->url)? $lang = "_".$lang_tab_title: $lang='';

                                       echo $form->field($model, 'title'.$lang)->textInput(['maxlength' => true]);

                                       echo $form->field($model, 'keywords'.$lang)->widget(
                                                Yii::$app->getModule('core')->wysiwyg_class_name(),
                                                Yii::$app->getModule('core')->wysiwyg_params()
                                            );

                                       echo $form->field($model, 'description'.$lang)->widget(
                                                Yii::$app->getModule('core')->wysiwyg_class_name(),
                                                Yii::$app->getModule('core')->wysiwyg_params()
                                            );

                                  echo '</div>';
                                 }
                            ?>
                            </div>
                        </div>
                    </div>
                    <div style="clear: both;"></div>
                    <?php BackendWidget::end(); ?>
              </article>

        </div>
    </section>

 <?php ActiveForm::end(); ?>

<div style="clear: both;"></div>
