<?php

/**
 * @var $model \app\modules\user\models\User
 * @var $propertyGroups \app\models\PropertyGroup[]
 * @var $services array
 * @var $this yii\web\View
 */

use kartik\widgets\ActiveForm;
use yii\authclient\widgets\AuthChoice;
use yii\helpers\Html;
use kartik\widgets\FileInput;

$this->title = Yii::t('app', 'Your profile');
$this->params['breadcrumbs'] = [
    [
        'label' => Yii::t('app', 'Personal cabinet'),
        'url' => ['/user/user/profile']
    ],
    $this->title,
];

$propertyGroups = $model->getPropertyGroups();

?>
<?php
$form = ActiveForm::begin([
    'id' => 'profile-form',
    'type' => ActiveForm::TYPE_VERTICAL,
    'options' => ['enctype' => 'multipart/form-data'],
]);
?>
<div class="row">
    <div class="col-md-6 col-sm-12">
        <h1 class="h2"><?= $this->title ?></h1>
        <style>
        .fileinput-remove-button
        {
            display: none;
        }
        </style>
        <? 
                $options = [];
                if ($model->isNewRecord === false) {
                    $this->registerCss('span.file-input > div.file-preview {display:block;}');
                    $this->registerCss('.file-preview img {max-width:100%;}');
                    $options = ['initialPreview' => [Html::img("/files/".$model->image)]];
                }
            echo $form->field($model, 'image')->widget(
                    FileInput::classname(),
                    [
                        'options' => ['accept' => 'image/*','multiple' => true],
                        'pluginOptions' => $options,
                    ]
             );?>
             
        <?= $form->field($model, 'first_name') ?>
        <?= $form->field($model, 'last_name') ?>
        <?= $form->field($model, 'email') ?>
        
        <?= $form->field($model, 'specialti_id')->dropDownList($model->getSpecialtisListData())?>
        <?= $form->field($model, 'clinic_id')->dropDownList($model->getClinicListData(),['prompt'=>'Select...'])?>
        
        <?= $form->field($model, 'city') ?>
        <?= $form->field($model, 'country') ?>
        <?= $form->field($model, 'phone') ?>
        <?= $form->field($model, 'website') ?>
        <?= $form->field($model, 'education')->textarea(['cols'=>10,'rows'=>5]) ?>
        <?= $form->field($model, 'experience')->textarea(['cols'=>10,'rows'=>5])  ?>
        <?= $form->field($model, 'job')->textarea(['cols'=>10,'rows'=>5])?>
        
        <div class="form-group">
            <?=
            Html::a(
                Yii::t('app', 'Change password'),
                ['/user/user/change-password']
            )
            ?>
        </div>
        <div class="form-group">
            <?=
            Html::a(
                Yii::t('app', 'Your files'),
                ['/user/user/files']
            )
            ?>
        </div>

    </div>
    <div class="col-md-6 col-sm-12">
        <?php foreach ($propertyGroups as $groupId => $properties): ?>

            <?php

            if (count($properties) > 0) {
                $group = \app\models\PropertyGroup::findById($groupId);
                if (intval($group->hidden_group_title) == 0) {
                    echo Html::tag('h2', $group->name);
                }

                $properties = app\models\Property::getForGroupId($groupId);

                foreach ($properties as $prop) {
                    $property_values = $model->getPropertyValuesByPropertyId($prop->id);


                    echo $prop->handler($form, $model->getAbstractModel(), $property_values, 'frontend_edit_view');


                }
            }
            ?>


        <?php endforeach; ?>
    </div>
</div>
<div class="row">
    <div class="col-md-12">
        <div class="form-group">
            <?= Html::submitButton(Yii::t('app', 'Save'), ['class' => 'btn btn-primary']) ?>
        </div>
    </div>
</div>
<div class="row">
    <div class="col-md-6 col-sm-12">
        <?php
        $authChoice = AuthChoice::begin([
            'baseAuthUrl' => ['/user/user/auth']
        ]);
        ?>
        <?php if (count($authChoice->clients) > count($services)): ?>
            <h3><?= Yii::t('app', 'Attach service') ?></h3>
            <ul class="auth-clients clear">
                <?php foreach ($authChoice->clients as $client): ?>
                    <?php if (!in_array($client->className(), $services)): ?>
                        <li class="auth-client"><?= $authChoice->clientLink($client) ?></li>
                    <?php endif; ?>
                <?php endforeach; ?>
            </ul>
        <?php endif; ?>
        <?php AuthChoice::end(); ?>
        <?php if (!empty($services)): ?>
            <h3><?= Yii::t('app', 'Detach service') ?></h3>
            <?php
            $authChoice = AuthChoice::begin([
                'baseAuthUrl' => ['/user/user/auth']
            ]);
            ?>
            <ul class="auth-clients clear">
                <?php foreach ($authChoice->clients as $client): ?>
                    <?php if (in_array($client->className(), $services)): ?>
                        <li class="auth-client"><?= $authChoice->clientLink($client) ?></li>
                    <?php endif; ?>
                <?php endforeach; ?>
            </ul>
            <?php AuthChoice::end(); ?>
        <?php endif; ?>
    </div>
</div>

<?php ActiveForm::end(); ?>
