<?php

use Yii;
use yii\helpers\Url;
use app\modules\medbase\assets\ClinicAsset;

ClinicAsset::register($this);

Yii::$app->view->registerMetaTag([
    'name' => 'description',
    'content' => $model->short_description,
]);
Yii::$app->view->registerMetaTag([
    'name' => 'keywords',
    'content' => $model->keywords,
]);

$this->title = $model->title;

?>
    <div class="content">
        <section class="page-top-title">
            <div class="container">
                <h1><?=$model->name?></h1>
            </div>
        </section>
        <div class="container">

            <div class="row">
                <div class="col-md-8">
                    <div class="main-item-panel margin-0-0-30-0">
                        <div class="main-item-panel-left">
                            <a class="image">
                                <img src="<?
                                if($model->getMainImage()->one())
                                    echo $model->getMainImage()->one()->getThumbnail('135','135');
                                else
                                    echo $model->getModelImage()->getThumbnailNotImage('135','135');

                                ?>">
                            </a>
                            <h3 class="raiting-total text-bold"><?=$model->getRaringCount()?></h3>
                            <div class="raiting-block no-caption">
                                <input value="<?=$model->getRaringCount()?>" type="text" class="rating-input_" disabled data-size="xs"/>
                            </div>
                            <span class="reviews-count"><?=$model->getReviewsCount()?> <?= Yii::t('app','review'); ?></span>
                            <div class="work-time">
                                <i class="fa fa-calendar" aria-hidden="true"></i>
                                <ul class="list-unstyled">
                                    <li>
                                        <span><?= Yii::t('app','ПН–ПТ'); ?></span>
                                        <span><?=$model->work_time_monday_friday?></span>
                                    </li>
                                    <li>
                                        <span><?= Yii::t('app','СБ'); ?></span>
                                        <span><?=$model->work_time_saturday?></span>
                                    </li>
                                    <li>
                                        <span><?= Yii::t('app','ВС'); ?></span>
                                        <span><?=$model->work_time_sunday?></span>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="main-item-panel-right">
                            <a class="name"><?=$model->name?></a>
                            <span class="speciality"><?=Yii::t('app','Клиника');?></span>
                            <div class="place-work-panel type-a">
                                <div class="place-work-address">
                                    <i class="fa fa-map-marker" aria-hidden="true"></i>
                                    <p><?=$model->address?></p>
                                </div>
                            </div>

                            <div class="description">
                                <?=$model->short_description?>
                            </div>

                            <ul class="list-unstyled contact-panel">
                                <li>
                                    <span><i class="fa fa-phone" aria-hidden="true"></i><?= Yii::t('app','телефон'); ?></span>
                                    <p>
                                        <?=$model->phone?>
                                    </p>
                                </li>
                                <?if($model->fax):?>
                                    <li>
                                        <span><i class="fa fa-fax" aria-hidden="true"></i><?= Yii::t('app','факс'); ?></span>
                                        <p>
                                            <?=$model->fax?>
                                        </p>
                                    </li>
                                <?endif?>
                                <?if($model->email):?>
                                    <li>
                                        <span><i class="fa fa-envelope" aria-hidden="true"></i> <?= Yii::t('app','эл. почта'); ?></span>
                                        <p>
                                            <?=$model->email?>
                                        </p>
                                    </li>
                                <?endif?>

                            </ul>
                            <ul class="list-unstyled stock-list">
                                <?
                                $i = 1;
                                foreach($model->getDiscountArray(date('Y-m-d',time())) as $discount):?>
                                    <li>
                                        <a href="<?=Url::to(['/page/page/detail','url'=>$discount['page_url']])?>" class="link-custom">
                                            <span><?=Yii::t('app','stock'); ?> ! </span>
                                            <p><?=$discount['short_description']?></p>
                                        </a>
                                    </li>
                                    <?
                                    if($i == 10)
                                        break;
                                    $i++;
                                endforeach;?>
                            </ul>
                        </div>
                        <div class="row">

                            <?if($parent OR $branches):?>
                                <div class="branches">
                                    <p><span><?=Yii::t('app','Филиалы клиники');?></span></p>

                                    <?if($parent):?>
                                        <?=$this->render('_min-item',['model'=>$parent])?>
                                    <?endif?>

                                    <? foreach($branches as $branche): ?>
                                        <?=$this->render('_min-item',['model'=>$branche])?>
                                    <? endforeach ?>
                                </div>
                            <?endif?>

                            <?if($images = $model->getImages(false)->all()):?>
                                <div class="gallrey-scroll-custom">

                                    <div id="gallrey-1">

                                        <div class="control-nav">
                                            <span class="prev"><i class="fa fa-angle-left" aria-hidden="true"></i></span>
                                            <span class="next"><i class="fa fa-angle-right" aria-hidden="true"></i></span>
                                        </div>
                                        <ul>
                                            <?foreach($images as $image):?>
                                                <li><a data-fancybox="gallery" href="<?=$image->file_name?>" style="background-image: url('<?=$image->getThumbnail(200,150)?>')"></a></li>
                                            <?endforeach?>
                                        </ul>
                                    </div>
                                </div>
                            <?endif?>
                            <div class="main-item-pane-bottom">
                                <ul class="nav nav-tabs type-a">
                                    <li class="active"><a href="#panel-1" data-toggle="tab" aria-expanded="true"><i class="fa fa-plus-square" aria-hidden="true"></i> <?=Yii::t('app','О клинке');?></a></li>
                                    <li><a href="#panel-2" data-toggle="tab" aria-expanded="false"><i class="fa fa-user-md" aria-hidden="true"></i><?=Yii::t('app','Врачи');?></a></li>
                                    <li><a href="#panel-3" data-toggle="tab" aria-expanded="true"><i class="fa fa-file-text-o" aria-hidden="true"></i><?=Yii::t('app','Цены');?></a></li>
                                    <li><a href="#panel-4" data-toggle="tab" aria-expanded="false"><i class="fa fa-commenting" aria-hidden="true"></i> <?=Yii::t('app','Отзывы');?> <?=$model->getReviewsCount()?></a></li>
                                    <li><a href="#panel-5" data-toggle="tab" aria-expanded="false"><i class="fa fa-newspaper-o" aria-hidden="true"></i> <?=Yii::t('app','Новости');?></a></li>
                                </ul>
                                <div class="tab-content">
                                    <div role="tabpanel" class="tab-pane fade active in" id="panel-1">
                                        <div class="raiting-statistics-panel">
                                            <div class="col-sm-8">
                                                <div class="row">
                                                    <div class="col-sm-6 ">
                                                        <p><?=Yii::t('app','Средний бал');?> </p>
                                                        <span class="text-bold font-size-40"><?=$model->getRaringCount()?></span>
                                                    </div>
                                                    <div class="col-sm-6 ">
                                                        <p><?=Yii::t('app','Кол-во отзывов');?></p>
                                                        <span class="text-bold font-size-40"><?=$model->getReviewsCount()?></span>
                                                    </div>
                                                    <div class="col-sm-9">
                                                        <p class="text"><i class="fa fa-star-half-full" aria-hidden="true"></i> <?=Yii::t('app','Рейтинг клиники рассчитывается на основе реальных отзывов пациентов');?></p>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="col-sm-4 ">
                                                <p><?=Yii::t('app','Рейтинг клиники');?></p>
                                                <div class="raiting-block no-caption">
                                                    <input value="<?=$model->rating?>" type="text" class="rating-input_" disabled data-size="xs"/>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="panel-border-top">
                                            <div class="col-xs-12">
                                                <?=$model->full_description?>
                                            </div>
                                        </div>
                                    </div>
                                    <div role="tabpanel" class="tab-pane fade" id="panel-2">
                                        <?=$this->render('doctors-list',['model'=>$model,'query_doctors'=>$model->getDoctors()]);?>
                                    </div>
                                    <div role="tabpanel" class="tab-pane fade" id="panel-4">
                                        <?=$this->render('_comment',['model'=>$model]);?>
                                    </div>
                                    <div role="tabpanel" class="tab-pane fade" id="panel-3">
                                        <?=$this->render('category-price',['model'=>$model]);?>
                                    </div>
                                    <div role="tabpanel" class="tab-pane fade" id="panel-5">
                                        <?=$this->render('_page-list',['model'=>$model,'query_page'=>$query_page]);?>
                                    </div>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="filter-panel">

                        <?

                        use dosamigos\google\maps\LatLng;
                        use dosamigos\google\maps\overlays\InfoWindow;
                        use dosamigos\google\maps\overlays\Marker;
                        use dosamigos\google\maps\Map;

                        $coord = new LatLng(['lat' => $model->lat, 'lng' => $model->lon]);

                        $map = new Map([
                            'center' => $coord,
                            'zoom' => 16,
                        ]);

                        // Lets add a marker now
                        $marker = new Marker([
                            'position' => $coord,
                            'title' => $model->name,
                            'icon' => '/img/map_marker.png'
                        ]);


                        // Provide a shared InfoWindow to the marker
                        $marker->attachInfoWindow(
                            new InfoWindow([
                                'content' => '<p>'. $model->name.'</p>'
                            ])
                        );

                        // Add marker to the map
                        $map->addOverlay($marker);
                        $map->width = '100%';

                        // Display the map -finally :)
                        echo $map->display();




                        /*



                        $center = new LatLng(['lat' => 41.32739077482725, 'lng' => 69.18462038040161]);


                        $marker = new \dosamigos\leaflet\layers\Marker(['latLng' => $center, 'popupContent' => 'Hi!']);

                        $tileLayer = new \dosamigos\leaflet\layers\TileLayer([
                            'urlTemplate' => 'http://otile{s}.mqcdn.com/tiles/1.0.0/map/{z}/{x}/{y}.jpeg',
                            'clientOptions' => [
                                'attribution' => 'Tiles Courtesy of <a href="http://www.mapquest.com/" target="_blank">MapQuest</a> ' .
                                    '<img src="http://developer.mapquest.com/content/osm/mq_logo.png">, ' .
                                    'Map data &copy; <a href="http://openstreetmap.org">OpenStreetMap</a> contributors, <a href="http://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a>',
                                'subdomains' => ['1', '2', '3', '4'],
                            ],
                        ]);


                        // now our component and we are going to configure it
                        $leaflet = new \dosamigos\leaflet\LeafLet([
                            'center' => $center, // set the center
                        ]);
                        // Different layers can be added to our map using the `addLayer` function.
                        $leaflet->addLayer($marker)      // add the marker
                        ->addLayer($tileLayer);  // add the tile layer

                        // finally render the widget
                        echo \dosamigos\leaflet\widgets\Map::widget(['leafLet' => $leaflet]);



                        */

                        ?>


                    </div>
                </div>
            </div>
        </div>

    </div>
    <style>
        #map {
            height: 400px;
            width: 100%;
        }
    </style>


<?
$js = "

    $('#gallrey-1').mThumbnailScroller({
            callbacks:{
                onInit:function(){
                    //$('#cppo').text(this.mts.leftPct+'%');

                    console.log(this.mts.left)
                        },
                onScrollStart:function(){
                    //cb('#ss');
                },
                whileScrolling:function(){
                    $('#cpo').text(this.mts.left);
                    $('#cppo').text(this.mts.leftPct+'%');
                    //cb('#is');
                },
                onScroll:function(){
                    //cb('#sc');
                },
                onTotalScroll:function(){
                    //cb('#ste');
                },
                onTotalScrollBack:function(){
                    //cb('#sts');
                }
            }
    });
    var loopDuration=6000;

    $('.control-nav span.next').hover(
            function(){
                $('#gallrey-1').mThumbnailScroller('scrollTo','right',{duration:loopDuration/2,easing:'easeInOutSmooth'});
            },
            function(){
                $('#gallrey-1').mThumbnailScroller('stop');
            }
    )

    $('.control-nav span.prev').hover(
        function(){
            $('#gallrey-1').mThumbnailScroller('scrollTo','left',{duration:loopDuration/2,easing:'easeInOutSmooth'});
            },
        function(){
            $('#gallrey-1').mThumbnailScroller('stop');
        }
    )

";
$this->registerJs($js);

?>